/*
 *
 * Copyright (C) 2010 Texas Instruments Incorporated - http://www.ti.com/ 
 * 
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/

/******************************************************************************
 * GGvf.CMD -  COMMAND FILE FOR LINKING DEVELOPMENT GOLDEN GATEWAY SOFTWARE
 *             ON 6608
 *             
 *
 *    Usage:       cl6x -z -el.cmd ggvf0.cmd
 *
 *    Description: This file is used to link development Golden Gateway software
 *                 on 6608
 *
 *    Notes: (1)   Be sure to use the right library!  Use a library that
 *                 matches the runtime model you are using.
 *
 *           (2)   You must specify the directory in which rts.lib is
 *                 located.  Either add a "-i<directory>" line to this
 *                 file, or use the system environment variable C_DIR to
 *                 specify a search path for libraries.
 *                                                     
 * TABS: NONE
 *
  *****************************************************************************/
/*****************************************************************************
 * All symbols in the command file are specified in their COFF format (which
 * has an extra _ compared to C).  The following (forward looking) aliases
 * allow linking for EABI (which doesn't add the leading _ in C).  The aliases
 * are defined for both EABI and COFF so the same command file can be used
 * for either.  One of the pair simply doesn't get used.
 *
 * Symbols defined in the same context don't need aliases at all.  This
 * means symbols defined in ASM can be used in ASM without aliases; likewise
 * symbols defined in C can be used in C without aliases.
 ****************************************************************************/
_bss_core_begin                = __bss_core_begin;
_bss_core_end                  = __bss_core_end;
_far1_core_begin               = __far1_core_begin;
_far1_core_end                 = __far1_core_end;
_far2_core_begin               = __far2_core_begin;
_far2_core_end                 = __far2_core_end;
_far_siuinst_core_begin        = __far_siuinst_core_begin;
_far_siuinst_core_end          = __far_siuinst_core_end;
_far_ext_core_begin            = __far_ext_core_begin;
_far_ext_core_end              = __far_ext_core_end;
ggvmmbuf                       = _ggvmmbuf;
_lcf_cppi_drv_start            = __lcf_cppi_drv_start;
_lcf_cppi_drv_end              = __lcf_cppi_drv_end;
_lcf_qmss_drv_start            = __lcf_qmss_drv_start;
_lcf_qmss_drv_end              = __lcf_qmss_drv_end;

_lcf_bios_fc_external_heap_begin = __lcf_bios_fc_external_heap_begin;
_lcf_bios_fc_external_heap_end   = __lcf_bios_fc_external_heap_end;
_lcf_bios_fc_internal_heap_begin = __lcf_bios_fc_internal_heap_begin;
_lcf_bios_fc_internal_heap_end   = __lcf_bios_fc_internal_heap_end;
_lcf_bios_fc_internal_scratch_begin = __lcf_bios_fc_internal_scratch_begin;
_lcf_bios_fc_internal_scratch_end   = __lcf_bios_fc_internal_scratch_end;


/*****************************************************************************
 * END of EABI/COFF aliases 
 *****************************************************************************/

-u=dsiuNwGlobInitConsts
--symbol_map dsiuNwGlobInit=dsiuNwGlobInitConsts

/******************************END OF FILE INCLUSION*************************/

/* Default flags */
-c                                         /* ROM autoinitialization module */
-a                                         /* LINK USING C CONVENTIONS      */

--generate_dead_funcs_list
--undef_sym=siuVctDiagAppMem

-x

/* SPECIFY THE SYSTEM MEMORY MAP */

MEMORY
{      
  /**************************************************************************
   *                 SHANNON MEMORY MAP
   *
   * Local L2:  0x0080_0000
   *            0x0087_FFFF  (512K)
   *
   * MSMC SRAM: 0x0C00_0000
   *            0x0C3F_FFFF  (4M)
   *
   * DDR via MPAX: see gghwcfg.h:HAL_MPAX_XMC_TBL
   * cacheability: see gghwcfg.h:HAL_MAR_REGS
   *
   *            0x8000 0000 - 0x9FFF FFFF
   ***************************************************************************/
  PAGE 0:
    DATA_SCRATCH        : origin = 0x800000,   length = 0x00620   /* Remember to change ggmemmap.beh (done)*/
    LL2_MISC            : origin = 0x800620,   length = 0x00830
    DATA_FAR_NONSHARED  : origin = 0x800E50,   length = 0x225C0
    VPPU_SCRATCH        : origin = 0x823410,   length = 0x00640   /* Remember to change ggmemmap.beh */
    FC_L2SCRATCH        : origin = 0x823A50,   length = 0x000C0
    MSG_FIFOS           : origin = 0x823B10,   length = 0x00010   /* Remember to change ggmemmap.beh (done)*/    
    DATA_GMP0           : origin = 0x823B20,   length = 0x00320   /* Remember to change ggmemmap.beh (done)*/
    LL2_TSIP_HOLE       : origin = 0x823E40,   length = 0x00100   /* Remember to change ggmemmap.beh (done)*/
    LL2_CIO             : origin = 0x823F40,   length = 0x00120
    DATA_HALHEAP        : origin = 0x824060,   length = 0x011C0   /* Remember to change ggmemmap.beh &ggswcfg.h; maxCh's *62 + 292  (done)*/
    LL2_VTK_CFG         : origin = 0x825220,   length = 0x005A0   /* VTK Configuration block */
    HAL_TDM_TX_BUFFER   : origin = 0x8257C0,   length = 0x00640   /* Remember to change ggswcfg.h (done)*/
    HAL_TDM_RX_BUFFER   : origin = 0x825E00,   length = 0x00640   /* Remember to change ggswcfg.h (done)*/
    EMU_PROF_VAR_INTMEM : origin = 0x826440,   length = 0x00040   /* poke variables in this mem to enable mips profiling */
    GMAC_NEU_BUFFERS    : origin = 0x826480,   length = 0x00500   /* Remember to change ggmemmap.beh (done)*/
    NEU_SCRATCH         : origin = 0x826980,   length = 0x00800   /* Remember to change ggmemmap.beh (done)*/
    /*DATA_STACK        : origin = 0x827180,   length = 0x04000*/ /* Remember this is defined in bios\platform.xs for data stack */
    /*BDATA             : origin = 0x82B180,   length = 0x01000 */ /*Remember this is defined in bios\platform.xs for BIOS data */
    LL2_BSS             : origin = 0x82C180,   length = 0x00158
    DATA_SIUINST        : origin = 0x82C2D8,   length = 0x00C08
	
    DATA_CH1        : origin = 0x82CEE0, length = 0x0F50  /* Remember to change ggmemmap.h */    
    DATA_CH2        : origin = 0x82DE30, length = 0x0F50  /* Remember to change ggmemmap.h */    
    
    FC_L2SRAM_DUMMY     : origin = 0x82ED80,   length = 0x00010
    /*FC_L2SRAM         : origin = 0x82ED90,   length = 0x01500*/ /*Remember this is defined in bios\platform.xs for FC */
    LL2_VTK             : origin = 0x830290,   length = 0x3FD70
    /* L2_CACHE         : origin = 0x870000,   length = 0x10000 */ /* 64 kb cache */

   /************ MSMC SRAM: 0xC000000-0xC3FFFFF *************/
    VECS                : origin = 0xC000000, length = 0x0200
    TEXT_ISRVEC         : origin = 0xC000200, length = 0x0460
    /* DSPIMAGE         : origin = 0xC000560, length = 0x0100  */  /* See page 4  */
    SWITCH              : origin = 0xC000660, length = 0x2000
    DATA_CINIT_HOLE     : origin = 0xC002660, length = 0x2000
    SL2_CONST_1         : origin = 0xC004660, length = 0xAAA0
    BOOT_CELL           : origin = 0xC00F100, length = 0x0100
    SL2_HOLE_1          : origin = 0xC00F200, length = 0x0660  
    DATA_EXT            : origin = 0xC00F860, length = 0x0300
    SL2_CONST_2         : origin = 0xC00FB60, length = 0x023D00
    PROG_SL2            : origin = 0xC033860, length = 0x0896A0
  /*BCODE               : origin = 0xC0BCF00, length = 0x01000 */ /*Remember this is defined in bios\platform.xs for BIOS code*/
    INT_CODEC_SHM       : origin = 0xC0BDF00, length = 0x2000
PAGE 2:
    DIAG_APP_VCT        : origin = 0xC0BFF00, length = 0x000100
PAGE 0:        
    DIAG_APP            : origin = 0xC0BFF00, length = 0x000100

    DATA_CINIT          : origin = 0xC0C0000, length = 0x8A160
    MSMC_HOLE_1         : origin = 0xC14A160, length = 0xB5EA0

    /*INT_IPC           : origin = 0xC200000, length = 0x8000*/  /*Remember this is defined in bios\platform.xs for BIOS IPC*/
  
    PROG_SL2_1          : origin = 0xC208000, length = 0x001F7F00
    DSIU_NW_GLOB_INIT   : origin = 0xC3FFF00, length = 0x00000100
  

  /*------------------------------------------------------------------------*/
  /* ---------------------- External DDR memory (0x80000000-0x9FFFFFFF) --- */
  /*------------------------------------------------------------------------*/
    DDR2_RAM            : origin = 0x80000000,  length = 0x000C33F0
    FC_DDR_DUMMY        : origin = 0x800C33F0,  length = 0x00000010
  /* Program in external memory */
    EXT_PROG            : origin = 0x800C3400,  length = 0x00166240
    EXT_CONST           : origin = 0x80229640,  length = 0x0010E9C0
    PR_GGMBUF_EXT       : origin = 0x80338000,  length = 0x00002000	
    EXT_CODEC_MEM_VIDEO : origin = 0x8033A000,  length = 0x05EF323A      /* Codec Instance data */
    EXT_CODEC_IO_TFTP   : origin = 0x88000000,  length = 0x01000000      /* Codec IO region for TFTP */
    EXT_CODEC_SHM       : origin = 0x89000000,  length = 0x02000000      /* Codec shared memory data */
    EXT_CODEC_IO_DATA   : origin = 0x8B000000,  length = 0x05000000      /* Codec IO region */
    
    EXT_MEM_UNCACHE     : origin = 0x90000000,  length = 0x00D00000      /* Non-cached for multi-core access */

    EXT_CODEC_MEM_A     : origin = 0x91000000,  length = 0x02000000      /* Codec Instance data - Slave A*/
    EXT_CODEC_MEM_IMAGE : origin = 0x93000000,  length = 0x03000000      /* Codec Instance data for image */
    EXT_CODEC_MEM_B     : origin = 0x96000000,  length = 0x02000000      /* Codec Instance data - Slave B*/
    EXT_CODEC_MEM_C     : origin = 0x98000000,  length = 0x02000000      /* Codec Instance data - Slave C*/
    EXT_CODEC_MEM_D     : origin = 0x9a000000,  length = 0x02000000      /* Codec Instance data - Slave D*/
    EXT_CODEC_MEM_E     : origin = 0x9c000000,  length = 0x02000000      /* Codec Instance data - Slave E*/

    QM_MEM_DESC_RAM         : origin = 0x9F000000, length = 0x00040000
    CPPI_MEM_TX_CTL_LINK_RAM: origin = 0x9F040000, length = 0x00060000
    CPPI_MEM_TX_PKT_LINK_RAM: origin = 0x9F0A0000, length = 0x00170000
    CPPI_MEM_RX_CTL_LINK_RAM: origin = 0x9F210000, length = 0x00060000
    CPPI_MEM_RX_PKT_LINK_RAM: origin = 0x9F270000, length = 0x001E6000
    DSIU_NWAL_GLOB_CONTEXT  : origin = 0x9F456000  length = 0x00000B50
    NWAL_PA_BUF             : origin = 0x9F456B50, length = 0x00006000
    CPPI_DRV                : origin = 0x9F45CB50, length = 0x00000400
    QMSS_DRV                : origin = 0x9F45CF50, length = 0x00002500

    /*************************************************************************
     * CODEC_SCRATCH_MCS: Aliased memory which "backs" CODEC_SCRATCH at 0xF000 0000
     * There is 0x40000 per core.  This must match gghwcfg.h:HAL_MPAX_XMC_TBL
     * The 0x40000 length must match CODEC_SCRATCH section size
     * This corresponds to physical memory 0x8 1FE0 0000
     *
     * This memory is RESERVED for normal placement through this cmd file
     *************************************************************************/
    CODEC_SCRATCH_RES           : origin = 0x9FE00000, length = 0x00200000
    /*************************************************************************
     * CODEC_SCRATCH is the logical address for the data channels.  This address must 
     * match the logical address in gghwcfg.h:HAL_MPAX_XMC_TBL
     *
     * The logical address is used for normal placement through this cmd file
     *************************************************************************/
    CODEC_SCRATCH               : origin = 0xF0000000, length = 0x00040000

PAGE 4:
    DSPIMAGE            : origin = 0xC000560,    length = 0x0100    /* See page 4  */
   
}

/* SPECIFY THE SECTIONS ALLOCATION INTO MEMORY */

SECTIONS
{   
   ISRAM          > LL2_MISC PAGE 0
   EXTERNAL_CONST > EXT_CONST PAGE 0
  .params        > LL2_MISC PAGE 0
  .tables        > SL2_CONST_2 PAGE 0
  .vDebugNeuStreamerScratch > DDR2_RAM PAGE 0
  .vDebugMsgs    > DDR2_RAM PAGE 0
  .siuNumCoreInit > DDR2_RAM PAGE 0
  .siuVctMsgs >  DDR2_RAM  PAGE 0
  .siuVctGmpSim > DDR2_RAM PAGE 0
  .siuVctFileReadBuffer > EXT_CODEC_IO_TFTP PAGE 0
  .codec_input  : align(0x100) > EXT_CODEC_IO_DATA PAGE 0
  .codec_output : align(0x100) > EXT_CODEC_IO_DATA PAGE 0

  .codecRfcMap > EXT_CONST PAGE 0

  .init_array > LL2_MISC PAGE 0
  
  .text_start > VECS
  {
    *(.text:_c_int00)
  } PAGE 0

   GROUP (NEAR_DP_RELATIVE)
   {
    .neardata
    .rodata
    .bss
   }>LL2_BSS

  .const_vmmcomp   > SL2_CONST_1 
  {
      _ggvmmbuf = .; /* Not used unless compression is used -- placeholder */
  } PAGE 0

  .textsl2_h264mc_ext >> PROG_SL2_1       
  {
   *(.text:H264VDEC_TI_decode_sect2) 
   *(.text:H264VDEC_TI_recon_sect2)
   *(.text:H264VDEC_TI_cSect1)
   *(.text:H264VDEC_TI_decode_sect1) 
  
  }

  .textsl2_h264mc_sl2 >> PROG_SL2_1       
  {
   *(.text:H264VDEC_TI_recon_sect1) 
  } PAGE 0

  .const_h264mc_tables >> SL2_CONST_2 | SL2_CONST_1 | EXT_CONST
  {
     *(.const:H264VDEC_TI_dSect2)
  } PAGE 0  

  .textExt >> EXT_PROG
  {
    * (.initProg)
    * (.controlProg)
    * (.progOverlay)
  } PAGE 0

  .textsl2 >> PROG_SL2 | PROG_SL2_1
  {
    * (.pkt2tdmProg)
    * (.tdm2pktpkt2tdmProg)
    * (.isrProg)
    * (.tdm2pktProg)
    * (.text)
  } PAGE 0

  .multiCoreSync > EXT_MEM_UNCACHE
  .shared_variables: align(0x100) > EXT_MEM_UNCACHE

  .shared_mem_DDR2 > EXT_CODEC_SHM
  .shared_mem_SL2 > INT_CODEC_SHM 

  .switch   >  SWITCH     PAGE 0
  .cio      >  LL2_CIO PAGE 0

/**************************************/
/* DATA Buffers assignment            */
/**************************************/
  
  .gg_scratch      >  DATA_SCRATCH   PAGE 0
  .output_buffer_loc >  CODEC_SCRATCH   PAGE 0
  .gg_halheap      >  DATA_HALHEAP   PAGE 0
  .gg_neu_scratch  >  NEU_SCRATCH    PAGE 0
  .gg_gmndu_neu    >  GMAC_NEU_BUFFERS PAGE 0
  .gg_ndu_msg_fifos> MSG_FIFOS PAGE 0

   .gg_ch1     >  DATA_CH1 PAGE 0
   .gg_ch2     >  DATA_CH2 PAGE 0

   .gg_gmp0        >  DATA_GMP0   PAGE 0    
   .gg_tdm_dma_rx  > HAL_TDM_RX_BUFFER   PAGE 0
   .gg_tdm_dma_tx  > HAL_TDM_TX_BUFFER   PAGE 0
   .diagApp        > DIAG_APP PAGE 0
   .siuVctDiagAppMem > DIAG_APP_VCT PAGE 2
   .rttrace        > DATA_EXT PAGE 0
   .gg_siuheap_inst > DATA_EXT PAGE 0
   .gg_siuheap_inst_ext > DATA_EXT PAGE 0
   .gg_nonshared_bufs > LL2_MISC PAGE 0
   .vDebug         > DDR2_RAM PAGE 0
   .siuVctParseBuf > DDR2_RAM PAGE 0
   .testCodecExtMem > EXT_CODEC_MEM_VIDEO PAGE 0
   .testCodecExtMemImg > EXT_CODEC_MEM_IMAGE PAGE 0
   .testCodecExtMemAud > EXT_CODEC_MEM_IMAGE PAGE 0
   .testCodecIntMem > LL2_VTK PAGE 0
   .testCodecExtMemSlaveA> EXT_CODEC_MEM_A PAGE 0
   .testCodecExtMemSlaveB> EXT_CODEC_MEM_B PAGE 0
   .testCodecExtMemSlaveC> EXT_CODEC_MEM_C PAGE 0
   .testCodecExtMemSlaveD> EXT_CODEC_MEM_D PAGE 0
   .testCodecExtMemSlaveE> EXT_CODEC_MEM_E PAGE 0
   
  .dsiuNwGlobContext  > DSIU_NWAL_GLOB_CONTEXT   PAGE 0

  .nwalInstMem > NWAL_PA_BUF PAGE 0 type = NOINIT
  .nwalHandleMem > NWAL_PA_BUF PAGE 0 type = NOINIT
  .paBuf0 > NWAL_PA_BUF PAGE 0 type = NOINIT
  .paBuf1 > NWAL_PA_BUF PAGE 0 type = NOINIT
  .paBuf2  > NWAL_PA_BUF PAGE 0 type = NOINIT

  .QMemDescRam > QM_MEM_DESC_RAM PAGE 0 type = NOINIT    
  .cppiMemRXLinkRamQ1 > CPPI_MEM_RX_CTL_LINK_RAM PAGE 0 type = NOINIT
  .cppiMemTXLinkRamQ1 > CPPI_MEM_TX_CTL_LINK_RAM PAGE 0 type = NOINIT
  .cppiMemRXLinkRamQ2 > CPPI_MEM_RX_PKT_LINK_RAM PAGE 0 type = NOINIT
  .cppiMemTXLinkRamQ2 > CPPI_MEM_TX_PKT_LINK_RAM PAGE 0 type = NOINIT

  .cppi               > CPPI_DRV START(__lcf_cppi_drv_start) END(__lcf_cppi_drv_end) PAGE 0 type = NOINIT
  .qmss               > QMSS_DRV START(__lcf_qmss_drv_start) END(__lcf_qmss_drv_end) PAGE 0 type = NOINIT

  /* Fill the GLOB_INIT with fixed random value. Should match to DSIU_NW_GLOB_INIT_STATE_MAGIC1 */
  .dsiuNwGlobInit     > DSIU_NW_GLOB_INIT  PAGE 0  fill = 0x167eb0e7

  .far_siuinst: fill = 0x00 >   DATA_SIUINST
  {
        __far_siuinst_core_begin = .;
    *(.siuinst)
        __far_siuinst_core_end = .;
  } PAGE 0

  .cinit  >  DATA_CINIT
  {
          __core_cinit = .;
          /*
          *(.cinit)
          */
  } PAGE 0


  .const_ggmheap  >> DATA_EXT
  {
  } PAGE 0

  .const2  > SL2_CONST_1 | SL2_CONST_2 | EXT_CONST
  {
    *(.const)
  } PAGE 0

  .bss: > LL2_BSS
  {
          __bss_core_begin = .;
          * (.bss)
          __bss_core_end = .;
  } PAGE 0

    /* NOT SHARABLE ; HAS TO BE IN L2 */
  .nonsharedfar fill=0x00 > DATA_FAR_NONSHARED
  {
        __far2_core_begin = .;
        __far1_core_begin = .;
        __far_ext_core_begin = .;
        * (.far) 
        *(.fardata) 
        __far2_core_end = .;
        __far1_core_end = .;
        __far_ext_core_end = .;
  } PAGE 0

  .ipc_context > DATA_FAR_NONSHARED PAGE 0

  /* DSPIMAGE has bitmap of codecs and is used only by micro */
  /* It is not used by DSP and is placed in page 4           */
  DSP_IMAGE  >  DSPIMAGE PAGE 4


/* In sv04, the heaps are created from bios .cfg file */
/* The following two dummy sections are added to avoid compilation errors */
  .fcExtHeap > FC_DDR_DUMMY
  {
    __lcf_bios_fc_external_heap_begin = .;
    . += 0x10;
    __lcf_bios_fc_external_heap_end = .;
  } PAGE 0 type = NOINIT

  .fcIntHeap > FC_L2SRAM_DUMMY
  {
    __lcf_bios_fc_internal_heap_begin = .;
    . += 0x10;
    __lcf_bios_fc_internal_heap_end = .;
  } PAGE 0 type = NOINIT

  .fcIntScratch > FC_L2SCRATCH
  {
    __lcf_bios_fc_internal_scratch_begin = .;
    . += 0xC0;
    __lcf_bios_fc_internal_scratch_end = .;
  } PAGE 0 type = NOINIT

}
/* nothing past this point */
