/****************************************************************************
 * FILE PURPOSE: Allocation tables with addresses for memory buffers and heap
 ****************************************************************************
 * FILE NAME:  ggMBuf.bec
 *
 * DESCRIPTION:  This file contains the allocation table for all ECO memory
 *               buffers and voice/FAX heap for each channel. The allocation
 *               tables are constructed using the data structures defined in
 *               ggmbuf.h and the memory map data in ggmemmap.h.  The
 *               allocation tables are global variables.  It is crucial that
 *               SIU checks the number of buffers for each ECO in the
 *               memory allocation table with the number actually requested
 *               by the ECO.  As a rule, when the buffer address is NULL SIU
 *               allocations the memory buffer from the heap.
 *
 * TABS: NONE
 *
 * $Id: ggmbuf.c 1.00 2002/05/12 K Aravindhan Exp $
 *
 * REVISION HISTORY:
 *
 * $Log: ggmbuf.c $
 *
 * (C) Copyright 2002, Texas Instruments
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/

#include "ggChBufDesc.h"
#include "ggmemmap.h"
#include "ggcfg.h"
#include "ggswcfg.h"

const ggchBuffDesc_t ggchBuffDesc[GG_MAX_NUM_SLOTS]=
{
  /* NUMSL is passed through mkrel/makefile and is visible to blockexpn.pl.
   * It is used by makegg to define GG_MAX_NUM_CHANNELS 
   */
  /* Expanding $ch = 1 */

  /*=======================================================================*/
  /* Channel 1 */
  /*=======================================================================*/
#ifdef GG_INCLUDE_PCM
  GG_NUM_ENC_PCM_BUFF,                                    /* VCA Buffers */

  (word *)GG_PCM_ENC_B0_C1_START,     GG_PCM_ENC_B0_C1_L,      /* C1 B0 */
#endif

#ifdef GG_INCLUDE_G726

  GG_NUM_ENC_ADPCM_BUFF,                                 /* ADPCM Buffers */
  (word *)GG_ADPCM_ENC_B0_C1_START,   GG_ADPCM_ENC_B0_C1_L,    /* C1 B0 */  
  (word *)GG_ADPCM_ENC_B1_C1_START,   GG_ADPCM_ENC_B1_C1_L,    /* C1 B1 */
  (word *)GG_ADPCM_ENC_B2_C1_START,   GG_ADPCM_ENC_B2_C1_L,    /* C1 B1 */
#endif
  
#ifdef GG_INCLUDE_G729AB

  GG_NUM_ENC_G729AB_BUFF,                                    /* G729AB Buffers */

  (word *)GG_G729AB_ENC_B0_C1_START,  GG_G729AB_ENC_B0_C1_L,   /* C1 B0 */    
  (word *)GG_G729AB_ENC_B1_C1_START,  GG_G729AB_ENC_B1_C1_L,   /* C1 B1 */    
  (word *)GG_G729AB_ENC_B2_C1_START,  GG_G729AB_ENC_B2_C1_L,   /* C1 B2 */    
  (word *)GG_G729AB_ENC_B3_C1_START,  GG_G729AB_ENC_B3_C1_L,   /* C1 B3 */    
  (word *)GG_G729AB_ENC_B4_C1_START,  GG_G729AB_ENC_B4_C1_L,   /* C1 B4 */    
  (word *)GG_G729AB_ENC_B5_C1_START,  GG_G729AB_ENC_B5_C1_L,   /* C1 B5 */    
  (word *)GG_G729AB_ENC_B6_C1_START,  GG_G729AB_ENC_B6_C1_L,   /* C1 B6 */    
  (word *)GG_G729AB_ENC_B7_C1_START,  GG_G729AB_ENC_B7_C1_L,   /* C1 B7 */    
  (word *)GG_G729AB_ENC_B8_C1_START,  GG_G729AB_ENC_B8_C1_L,   /* C1 B8 */
  0x0000,0x0000,
  0x0000,0x0000,
  0x0000,0x0000,
#endif

#ifdef GG_INCLUDE_G729    

  GG_NUM_ENC_G729_BUFF,                                        /* G729 Buffers  */
  0x0000,0x0000,                                                /* C1 B0 */
  0x0000,0x0000,                                                /* C1 B1 */
  0x0000,0x0000,                                                /* C1 B2 */
  0x0000,0x0000,                                                /* C1 B3 */
  0x0000,0x0000,                                                /* C1 B4 */
  0x0000,0x0000,                                                /* C1 B5 */
#endif
  
#ifdef GG_INCLUDE_G729E    
  GG_NUM_ENC_G729E_BUFF,                                       /* G729E Buffers */
  0x0000,0x0000,                                                /* C1 B0 */
  0x0000,0x0000,                                                /* C1 B1 */
  0x0000,0x0000,                                                /* C1 B2 */
  0x0000,0x0000,                                                /* C1 B3 */
  0x0000,0x0000,                                                /* C1 B4 */
  0x0000,0x0000,                                                /* C1 B5 */
  0x0000,0x0000,                                                /* C1 B6 */
  0x0000,0x0000,                                                /* C1 B7 */
  0x0000,0x0000,                                                /* C1 B8 */
  0x0000,0x0000,                                                /* C1 B9 */
  0x0000,0x0000,                                                /* C1 B10 */
  0x0000,0x0000,                                                /* C1 B11 */
#endif

#ifdef GG_INCLUDE_G723    
  GG_NUM_ENC_G723_BUFF,                                        /* G723 Buffers */
  (word *)GG_G723_ENC_B0_C1_START,    GG_G723_ENC_B0_C1_L,     /* C1 B0 */
  (word *)GG_G723_ENC_B1_C1_START,    GG_G723_ENC_B1_C1_L,     /* C1 B1 */
  (word *)GG_G723_ENC_B2_C1_START,    GG_G723_ENC_B2_C1_L,     /* C1 B2 */
  (word *)GG_G723_ENC_B3_C1_START,    GG_G723_ENC_B3_C1_L,     /* C1 B3 */
  (word *)GG_G723_ENC_B4_C1_START,    GG_G723_ENC_B4_C1_L,     /* C1 B4 */
  (word *)GG_G723_ENC_B5_C1_START,    GG_G723_ENC_B5_C1_L,     /* C1 B5 */
#endif
  
#ifdef GG_INCLUDE_G728    
  GG_NUM_ENC_G728_BUFF,                                        /* G728 Buffers  */
  0x0000,0x0000,                                                /* C1 B0 */
  0x0000,0x0000,                                                /* C1 B1 */
  0x0000,0x0000,                                                /* C1 B2 */
  0x0000,0x0000,                                                /* C1 B3 */
  0x0000,0x0000,                                                /* C1 B4 */
  0x0000,0x0000,                                                /* C1 B5 */
  0x0000,0x0000,                                                /* C1 B6 */
#endif

#ifdef GG_INCLUDE_GSMEFR  
  GG_NUM_ENC_GSMEFR_BUFF,                                  /* GSM EFR Buffers */
  0x0000,0x0000,                                                /* C1 B0  */
  0x0000,0x0000,                                                /* C1 B1  */
  0x0000,0x0000,                                                /* C1 B2  */
  0x0000,0x0000,                                                /* C1 B3  */
  0x0000,0x0000,                                                /* C1 B4  */
  0x0000,0x0000,                                                /* C1 B5  */
  0x0000,0x0000,                                                /* C1 B6  */
#endif
  
#ifdef GG_INCLUDE_GSMFR  
  GG_NUM_ENC_GSMFR_BUFF,                                  /* GSM FR Buffers */
  (word *) GG_GSMFR_ENC_B0_C1_START, GG_GSMFR_ENC_B0_C1_L, /* C1 B0 */
  (word *) GG_GSMFR_ENC_B1_C1_START, GG_GSMFR_ENC_B1_C1_L, /* C1 B1 */
  (word *) GG_GSMFR_ENC_B2_C1_START, GG_GSMFR_ENC_B2_C1_L, /* C1 B2 */
  0x0000,0x0000,                                                   /* C1 B3 */
#endif
  
#ifdef GG_INCLUDE_G722 
  GG_NUM_ENC_G722_BUFF,                                        /* G722 Buffers */
  0x0000,0x0000,                                                /* C1 B0 */
  0x0000,0x0000,                                                /* C1 B1 */ 
  0x0000,0x0000,                                                /* C1 B2 */
  0x0000,0x0000,                                                /* C1 B3 */
  0x0000,0x0000,                                                /* C1 B4 */
#endif

#ifdef GG_INCLUDE_ILBC  
  GG_NUM_ENC_ILBC_BUFF,

  (word *)GG_ILBC_ENC_B0_C1_START,   GG_ILBC_ENC_B0_C1_L,    /* C1 B0 */
  (word *)GG_ILBC_ENC_B1_C1_START,   GG_ILBC_ENC_B1_C1_L,    /* C1 B1 */
  (word *)GG_ILBC_ENC_B2_C1_START,   GG_ILBC_ENC_B2_C1_L,    /* C1 B2 */
  (word *)0,0,
#endif



#ifdef GG_INCLUDE_GSMAMR                                      
  GG_NUM_ENC_GSMAMR_BUFF,                                              /* GSMAMR Buffers*/

  (word *)GG_GSMAMR_ENC_B0_C1_START,    GG_GSMAMR_ENC_B0_C1_L,     /* C1 B0 */
  (word *)GG_GSMAMR_ENC_B1_C1_START,    GG_GSMAMR_ENC_B1_C1_L,     /* C1 B1 */
  (word *)GG_GSMAMR_ENC_B2_C1_START,    GG_GSMAMR_ENC_B2_C1_L,     /* C1 B2 */
  (word *)GG_GSMAMR_ENC_B3_C1_START,    GG_GSMAMR_ENC_B3_C1_L,     /* C1 B3 */
  (word *)GG_GSMAMR_ENC_B4_C1_START,    GG_GSMAMR_ENC_B4_C1_L,     /* C1 B4 */
  (word *)GG_GSMAMR_ENC_B5_C1_START,    GG_GSMAMR_ENC_B5_C1_L,     /* C1 B5 */
  (word *)GG_GSMAMR_ENC_B6_C1_START,    GG_GSMAMR_ENC_B6_C1_L,     /* C1 B6 */
  (word *)GG_GSMAMR_ENC_B7_C1_START,    GG_GSMAMR_ENC_B7_C1_L,     /* C1 B7 */
  (word *)GG_GSMAMR_ENC_B8_C1_START,    GG_GSMAMR_ENC_B8_C1_L,     /* C1 B8 */
  (word *)GG_GSMAMR_ENC_B9_C1_START,    GG_GSMAMR_ENC_B9_C1_L,     /* C1 B9 */
#endif

#ifdef GG_INCLUDE_GG_INCLUDE_G722_2                                      
  GG_NUM_ENC_GSM_WBAMR_BUFF,                                              /* GSM_WBAMR Buffers*/
  (word *)GG_GSM_WBAMR_ENC_B0_C1_START,    GG_GSM_WBAMR_ENC_B0_C1_L,     /* C1 B0 */
  (word *)GG_GSM_WBAMR_ENC_B1_C1_START,    GG_GSM_WBAMR_ENC_B1_C1_L,     /* C1 B1 */
  (word *)GG_GSM_WBAMR_ENC_B2_C1_START,    GG_GSM_WBAMR_ENC_B2_C1_L,     /* C1 B2 */
  (word *)GG_GSM_WBAMR_ENC_B3_C1_START,    GG_GSM_WBAMR_ENC_B3_C1_L,     /* C1 B3 */
  (word *)GG_GSM_WBAMR_ENC_B4_C1_START,    GG_GSM_WBAMR_ENC_B4_C1_L,     /* C1 B4 */
  (word *)GG_GSM_WBAMR_ENC_B5_C1_START,    GG_GSM_WBAMR_ENC_B5_C1_L,     /* C1 B5 */
#endif


#ifdef GG_INCLUDE_EVRC
  GG_NUM_ENC_EVRC_BUFF,                                        /* EVRC/EVRC Buffers */   
  (word *)GG_EVRC_ENC_B0_C1_START,  GG_EVRC_ENC_B0_C1_L,   /* C1 B0 */
  (word *)GG_EVRC_ENC_B1_C1_START,  GG_EVRC_ENC_B1_C1_L,   /* C1 B1 */
  (word *)GG_EVRC_ENC_B2_C1_START,  GG_EVRC_ENC_B2_C1_L,   /* C1 B2 */
  (word *)GG_EVRC_ENC_B3_C1_START,  GG_EVRC_ENC_B3_C1_L,   /* C1 B3 */
  (word *)GG_EVRC_ENC_B4_C1_START,  GG_EVRC_ENC_B4_C1_L,   /* C1 B4 */
  (word *)GG_EVRC_ENC_B5_C1_START,  GG_EVRC_ENC_B5_C1_L,   /* C1 B5 */
  (word *)GG_EVRC_ENC_B6_C1_START,  GG_EVRC_ENC_B6_C1_L,   /* C1 B6 */
#endif

#ifdef GG_INCLUDE_SMV                                       
  GG_NUM_ENC_SMV_BUFF,                                         /* SMV */ 
  (word *)GG_SMV_ENC_B0_C1_START,  GG_SMV_ENC_B0_C1_L,   /* C1 B0 */
  (word *)GG_SMV_ENC_B1_C1_START,  GG_SMV_ENC_B1_C1_L,   /* C1 B1 */
  (word *)GG_SMV_ENC_B2_C1_START,  GG_SMV_ENC_B2_C1_L,   /* C1 B2 */
  (word *)0,0,
#endif
#ifdef GG_INCLUDE_QCELP13
 GG_NUM_ENC_QCELP13_BUFF,                                         /* QCELP13 Buffers   */
  (word *)GG_QCELP13_ENC_B0_C1_START,  GG_QCELP13_ENC_B0_C1_L,   /* C1 B0  */
  (word *)GG_QCELP13_ENC_B1_C1_START,  GG_QCELP13_ENC_B1_C1_L,   /* C1 B1   */
  (word *)GG_QCELP13_ENC_B2_C1_START,  GG_QCELP13_ENC_B2_C1_L,   /* C1 B2   */
  (word *)GG_QCELP13_ENC_B3_C1_START,  GG_QCELP13_ENC_B3_C1_L,   /* C1 B3  */
  (word *)GG_QCELP13_ENC_B4_C1_START,  GG_QCELP13_ENC_B4_C1_L,   /* C1 B4   */
  (word *)GG_QCELP13_ENC_B5_C1_START,  GG_QCELP13_ENC_B5_C1_L,   /* C1 B5   */
  (word *)GG_QCELP13_ENC_B6_C1_START,  GG_QCELP13_ENC_B6_C1_L,   /* C1 B6   */
  (word *)GG_QCELP13_ENC_B7_C1_START,  GG_QCELP13_ENC_B7_C1_L,   /* C1 B7   */
  (word *)GG_QCELP13_ENC_B8_C1_START,  GG_QCELP13_ENC_B8_C1_L,   /* C1 B8   */
#endif																	

#ifdef AUDIO
 #ifdef GG_INCLUDE_MP3
  GG_NUM_DEC_MP3_BUFF,                                                  /* MP3 No Encoder*/
  (word *)0,0,(word *)0,0, (word *)0,0, (word *)0,0,
  (word *)0,0,(word *)0,0, (word *)0,0, (word *)0,0,
  (word *)0,0,
 #endif
#endif

#ifdef GG_INCLUDE_PCM                                      
  GG_NUM_DEC_PCM_BUFF,                                        /* VCA Buffers */

  (word *)GG_PCM_DEC_B0_C1_START,     GG_PCM_DEC_B0_C1_L,      /* C1 B0 */
#endif

#ifdef GG_INCLUDE_G726

  GG_NUM_DEC_ADPCM_BUFF,                                    /* ADPCM Buffers */
  (word *)GG_ADPCM_DEC_B0_C1_START,   GG_ADPCM_DEC_B0_C1_L,    /* C1 B0 */  
  (word *)GG_ADPCM_DEC_B1_C1_START,   GG_ADPCM_DEC_B1_C1_L,    /* C1 B1 */
  (word *)GG_ADPCM_DEC_B2_C1_START,   GG_ADPCM_DEC_B2_C1_L,    /* C1 B1 */
#endif

#ifdef GG_INCLUDE_G729AB  

  GG_NUM_DEC_G729AB_BUFF,                                   /* G729AB Buffers */

  (word *)GG_G729AB_DEC_B0_C1_START,  GG_G729AB_DEC_B0_C1_L,   /* C1 B0 */    
  (word *)GG_G729AB_DEC_B1_C1_START,  GG_G729AB_DEC_B1_C1_L,   /* C1 B1 */    
  (word *)GG_G729AB_DEC_B2_C1_START,  GG_G729AB_DEC_B2_C1_L,   /* C1 B2 */    
  (word *)GG_G729AB_DEC_B3_C1_START,  GG_G729AB_DEC_B3_C1_L,   /* C1 B3 */    
  (word *)GG_G729AB_DEC_B4_C1_START,  GG_G729AB_DEC_B4_C1_L,   /* C1 B4 */    
  (word *)GG_G729AB_DEC_B5_C1_START,  GG_G729AB_DEC_B5_C1_L,   /* C1 B5 */    
  (word *)GG_G729AB_DEC_B6_C1_START,  GG_G729AB_DEC_B6_C1_L,   /* C1 B6 */    
  (word *)GG_G729AB_DEC_B7_C1_START,  GG_G729AB_DEC_B7_C1_L,   /* C1 B7 */    
  (word *)GG_G729AB_DEC_B8_C1_START,  GG_G729AB_DEC_B8_C1_L,   /* C1 B8 */    
  (word *)GG_G729AB_DEC_B9_C1_START,  GG_G729AB_DEC_B9_C1_L,   /* C1 B9 */    
  (word *)GG_G729AB_DEC_B10_C1_START, GG_G729AB_DEC_B10_C1_L,   /* C1 B10 */
  (word *)GG_G729AB_DEC_B11_C1_START, GG_G729AB_DEC_B11_C1_L,   /* C1 B11 */
#endif  
 
#ifdef GG_INCLUDE_G729  
  GG_NUM_DEC_G729_BUFF,                                        /* G729 Buffers */
  0x0000,0x0000,                                                /* C1 B0 */
  0x0000,0x0000,                                                /* C1 B1 */
  0x0000,0x0000,                                                /* C1 B2 */
  0x0000,0x0000,                                                /* C1 B3 */
  0x0000,0x0000,                                                /* C1 B4 */
  0x0000,0x0000,                                                /* C1 B5 */
#endif  

#ifdef GG_INCLUDE_G729E 
  GG_NUM_DEC_G729E_BUFF,                                       /* G729E Buffers */
  0x0000,0x0000,                                                /* C1 B0 */
  0x0000,0x0000,                                                /* C1 B1 */
  0x0000,0x0000,                                                /* C1 B2 */
  0x0000,0x0000,                                                /* C1 B3 */
  0x0000,0x0000,                                                /* C1 B4 */
  0x0000,0x0000,                                                /* C1 B5 */
  0x0000,0x0000,                                                /* C1 B6 */
  0x0000,0x0000,                                                /* C1 B7 */
  0x0000,0x0000,                                                /* C1 B8 */
  0x0000,0x0000,                                                /* C1 B9 */
  0x0000,0x0000,                                                /* C1 B10 */
  0x0000,0x0000,                                                /* C1 B11 */
#endif

#ifdef GG_INCLUDE_G723
  GG_NUM_DEC_G723_BUFF,                                        /* G723 Buffers */
  (word *)GG_G723_DEC_B0_C1_START,    GG_G723_DEC_B0_C1_L,     /* C1 B0 */
  (word *)GG_G723_DEC_B1_C1_START,    GG_G723_DEC_B1_C1_L,     /* C1 B1 */
  (word *)GG_G723_DEC_B2_C1_START,    GG_G723_DEC_B2_C1_L,     /* C1 B2 */
  (word *)GG_G723_DEC_B3_C1_START,    GG_G723_DEC_B3_C1_L,     /* C1 B3 */
  0x0000,0x0000, /* To match Encoder Buffers */                        /* C1 B5 */
  0x0000,0x0000, /* To match Encoder Buffers */                        /* C1 B5 */
#endif

#ifdef GG_INCLUDE_G728
  GG_NUM_DEC_G728_BUFF,                                        /* G728 Buffers */
  0x0000,0x0000,                                                /* C1 B0 */
  0x0000,0x0000,                                                /* C1 B1 */
  0x0000,0x0000,                                                /* C1 B2 */
  0x0000,0x0000,                                                /* C1 B3 */
  0x0000,0x0000,                                                /* C1 B4 */
  0x0000,0x0000,                                                /* C1 B5 */
  0x0000,0x0000,                                                /* C1 B6 */
#endif
  
#ifdef GG_INCLUDE_GSMEFR
  GG_NUM_DEC_GSMEFR_BUFF,                                  /* GSM EFR Buffers */
  0x0000,0x0000,                                                /* C1 B0  */
  0x0000,0x0000,                                                /* C1 B1  */
  0x0000,0x0000,                                                /* C1 B2  */
  0x0000,0x0000,                                                /* C1 B3  */
  0x0000,0x0000,                                                /* C1 B4  */
  0x0000,0x0000,                                                /* C1 B5  */
  0x0000,0x0000,                                                /* C1 B6  */
#endif

#ifdef GG_INCLUDE_GSMFR  
  GG_NUM_DEC_GSMFR_BUFF,                                   /* GSM FR Buffers */
  (word *) GG_GSMFR_DEC_B0_C1_START, GG_GSMFR_DEC_B0_C1_L, /* C1 B0 */
  (word *) GG_GSMFR_DEC_B1_C1_START, GG_GSMFR_DEC_B1_C1_L, /* C1 B1 */
  (word *) GG_GSMFR_DEC_B2_C1_START, GG_GSMFR_DEC_B2_C1_L, /* C1 B2 */
  (word *) GG_GSMFR_DEC_B3_C1_START, GG_GSMFR_DEC_B3_C1_L, /* C1 B3 */
#endif


#ifdef GG_INCLUDE_G722 
  GG_NUM_DEC_G722_BUFF,                                        /* G722 Buffers*/
  0x0000,0x0000,                                                /* C1 B0 */
  0x0000,0x0000,                                                /* C1 B1 */
  0x0000,0x0000,                                                /* C1 B2 */
  0x0000,0x0000,                                                /* C1 B3 */
  0x0000,0x0000,                                                /* C1 B4 */
#endif

#ifdef GG_INCLUDE_ILBC
  GG_NUM_DEC_ILBC_BUFF,

  (word *)GG_ILBC_DEC_B0_C1_START,   GG_ILBC_DEC_B0_C1_L,    /* C1 B0 */
  (word *)GG_ILBC_DEC_B1_C1_START,   GG_ILBC_DEC_B1_C1_L,    /* C1 B1 */
  (word *)GG_ILBC_DEC_B2_C1_START,   GG_ILBC_DEC_B2_C1_L,    /* C1 B1 */
  (word *)GG_ILBC_DEC_B3_C1_START,   GG_ILBC_DEC_B3_C1_L,    /* C1 B1 */
#endif



#ifdef GG_INCLUDE_GSMAMR
  GG_NUM_DEC_GSMAMR_BUFF,                                              /* GSMAMR Buffers*/

  (word *)GG_GSMAMR_DEC_B0_C1_START,    GG_GSMAMR_DEC_B0_C1_L,     /* C1 B0 */
  (word *)GG_GSMAMR_DEC_B1_C1_START,    GG_GSMAMR_DEC_B1_C1_L,     /* C1 B1 */
  (word *)GG_GSMAMR_DEC_B2_C1_START,    GG_GSMAMR_DEC_B2_C1_L,     /* C1 B2 */
  (word *)GG_GSMAMR_DEC_B3_C1_START,    GG_GSMAMR_DEC_B3_C1_L,     /* C1 B3 */
  (word *)GG_GSMAMR_DEC_B4_C1_START,    GG_GSMAMR_DEC_B4_C1_L,     /* C1 B3 */
  (word *)0,0,
  (word *)0,0,
  (word *)0,0,
  (word *)0,0,
  (word *)0,0,
#endif


#ifdef GG_INCLUDE_G722_2
  GG_NUM_DEC_GSM_WBAMR_BUFF,                                              /* GSM_WBAMR Buffers*/

  (word *)GG_GSM_WBAMR_DEC_B0_C1_START,    GG_GSM_WBAMR_DEC_B0_C1_L,     /* C1 B0 */
  (word *)GG_GSM_WBAMR_DEC_B1_C1_START,    GG_GSM_WBAMR_DEC_B1_C1_L,     /* C1 B1 */
  (word *)GG_GSM_WBAMR_DEC_B2_C1_START,    GG_GSM_WBAMR_DEC_B2_C1_L,     /* C1 B2 */
  (word *)GG_GSM_WBAMR_DEC_B3_C1_START,    GG_GSM_WBAMR_DEC_B3_C1_L,     /* C1 B3 */
  (word *)GG_GSM_WBAMR_DEC_B4_C1_START,    GG_GSM_WBAMR_DEC_B4_C1_L,     /* C1 B4 */
  (word *)GG_GSM_WBAMR_DEC_B5_C1_START,    GG_GSM_WBAMR_DEC_B5_C1_L,     /* C1 B5 */  


#endif


#ifdef GG_INCLUDE_EVRC                                       
  GG_NUM_DEC_EVRC_BUFF,                                         /* EVRC/EVRC Buffers */   
  (word *)GG_EVRC_DEC_B0_C1_START,  GG_EVRC_DEC_B0_C1_L,   /* C1 B0 */
  (word *)GG_EVRC_DEC_B1_C1_START,  GG_EVRC_DEC_B1_C1_L,   /* C1 B1 */
  (word *)GG_EVRC_DEC_B2_C1_START,  GG_EVRC_DEC_B2_C1_L,   /* C1 B2 */
  (word *)GG_EVRC_DEC_B3_C1_START,  GG_EVRC_DEC_B3_C1_L,   /* C1 B2 */
  0, 0,	0, 0, 0, 0, 
#endif

#ifdef GG_INCLUDE_SMV                                       
  GG_NUM_DEC_SMV_BUFF,
  (word *)GG_SMV_DEC_B0_C1_START,  GG_SMV_DEC_B0_C1_L,   /* C1 B0 */
  (word *)GG_SMV_DEC_B1_C1_START,  GG_SMV_DEC_B1_C1_L,   /* C1 B1 */
  (word *)GG_SMV_DEC_B2_C1_START,  GG_SMV_DEC_B2_C1_L,   /* C1 B2 */
  (word *)GG_SMV_DEC_B3_C1_START,  GG_SMV_DEC_B3_C1_L,   /* C1 B3 */
#endif

#ifdef GG_INCLUDE_QCELP13
  GG_NUM_DEC_QCELP13_BUFF,                                         /* QCELP13 Buffers */   	
  (word *)GG_QCELP13_DEC_B0_C1_START,  GG_QCELP13_DEC_B0_C1_L,   /* C1 B0 */	
  (word *)GG_QCELP13_DEC_B1_C1_START,  GG_QCELP13_DEC_B1_C1_L,   /* C1 B1 */	
  (word *)GG_QCELP13_DEC_B2_C1_START,  GG_QCELP13_DEC_B2_C1_L,   /* C1 B2 */	
  (word *)GG_QCELP13_DEC_B3_C1_START,  GG_QCELP13_DEC_B3_C1_L,   /* C1 B3 */	
  (word *)GG_QCELP13_DEC_B4_C1_START,  GG_QCELP13_DEC_B4_C1_L,   /* C1 B4 */	
  0, 0,	0, 0, 0, 0, 0, 0,																				
#endif																	

#ifdef AUDIO
 #ifdef GG_INCLUDE_MP3
  GG_NUM_DEC_MP3_BUFF,                                                /* MP3 Buffers*/
  (word *)GG_MP3_DEC_B0_C1_START,    GG_MP3_DEC_B0_C1_L,     /* C1 B0 */
  (word *)GG_MP3_DEC_B1_C1_START,    GG_MP3_DEC_B1_C1_L,     /* C1 B1 */
  (word *)GG_MP3_DEC_B2_C1_START,    GG_MP3_DEC_B2_C1_L,     /* C1 B2 */
  (word *)GG_MP3_DEC_B3_C1_START,    GG_MP3_DEC_B3_C1_L,     /* C1 B3 */
  (word *)GG_MP3_DEC_B4_C1_START,    GG_MP3_DEC_B4_C1_L,     /* C1 B4 */
  (word *)GG_MP3_DEC_B5_C1_START,    GG_MP3_DEC_B5_C1_L,     /* C1 B5 */
  (word *)GG_MP3_DEC_B6_C1_START,    GG_MP3_DEC_B6_C1_L,     /* C1 B6 */
  (word *)GG_MP3_DEC_B7_C1_START,    GG_MP3_DEC_B7_C1_L,     /* C1 B7 */
  (word *)GG_MP3_DEC_B8_C1_START,    GG_MP3_DEC_B8_C1_L,     /* C1 B7 */
 #endif
#endif

#if defined(VOICE) || defined(VOICE_FAX)    
  GG_NUM_VCU_BUFF,                                             /* VCU Buffers */
#ifndef GG_VCU_C1_HEAP_ALLOC
  (word *)GG_VCU_B0_C1_START,         GG_VCU_B0_C1_L,          /* C1 B0 */
  #if (defined(GG_TFO_IPE) || defined(GG_TFO_AE))
  (word *)GG_VCU_B1_C1_START,         GG_VCU_B1_C1_L,          /* C1 B1 */
  #endif
#else
  0,0, 
  #if (defined(GG_TFO_IPE) || defined(GG_TFO_AE))
  0,0,          
  #endif
#endif
#endif

#if defined(VOICE) || defined(VOICE_FAX)    
  GG_NUM_VAU_BUFF,                                                   /* VAU Buffers */
#ifndef GG_VAU_C1_HEAP_ALLOC
  (word *)GG_VAU_B0_C1_START,         GG_VAU_B0_C1_L,          /* C1 B0 */
  (word *)GG_VAU_B1_C1_START,         GG_VAU_B1_C1_L,          /* C1 B1 */
  (word *)GG_VAU_B2_C1_START,         GG_VAU_B2_C1_L,          /* C1 B2 */
#else
  0,0, 0,0, 0,0,  
#endif
#endif

#ifdef GG_INCLUDE_ECU
  GG_NUM_ECU_BUFF,                                                   /* ECU Buffers */

  (word *)GG_ECU_B0_C1_START,         GG_ECU_B0_C1_L,          /* C1 B0 */
  (word *)GG_ECU_B1_C1_START,         GG_ECU_B1_C1_L,          /* C1 B1 */
  (word *)GG_ECU_B2_C1_START,         GG_ECU_B2_C1_L,          /* C1 B2 */
  (word *)GG_ECU_B3_C1_START,         GG_ECU_B3_C1_L,          /* C1 B3 */
  (word *)GG_ECU_B4_C1_START,         GG_ECU_B4_C1_L,          /* C1 B4 */
  (word *)GG_ECU_B5_C1_START,         GG_ECU_B5_C1_L,          /* C1 B5 */
  (word *)GG_ECU_B6_C1_START,         GG_ECU_B6_C1_L,          /* C1 B6 */
  (word *)GG_ECU_B7_C1_START,         GG_ECU_B7_C1_L,          /* C1 B7 */
  (word *)GG_ECU_B8_C1_START,         GG_ECU_B8_C1_L,          /* C1 B8 */
  (word *)GG_ECU_B9_C1_START,         GG_ECU_B9_C1_L,          /* C1 B9 */
  (word *)GG_ECU_B10_C1_START,        GG_ECU_B10_C1_L,         /* C1 B10 */
  (word *)GG_ECU_B11_C1_START,        GG_ECU_B11_C1_L,         /* C1 B11 */
  (word *)GG_ECU_B12_C1_START,        GG_ECU_B12_C1_L,         /* C1 B12 */
  (word *)GG_ECU_B13_C1_START,        GG_ECU_B13_C1_L,         /* C1 B13 */
  (word *)GG_ECU_B14_C1_START,        GG_ECU_B14_C1_L,         /* C1 B14 */
#endif

#ifdef LEC_TECENG
  GG_NUM_TECENG_CH_BUFF,
  
  (word *)GG_TEC_CH_B0_C1_START,         GG_TEC_CH_B0_C1_L,          /* C1 B4 */
  (word *)GG_TEC_CH_B1_C1_START,         GG_TEC_CH_B1_C1_L,          /* C1 B5 */
  (word *)GG_TEC_CH_B2_C1_START,         GG_TEC_CH_B2_C1_L,          /* C1 B6 */
  (word *)GG_TEC_CH_B3_C1_START,         GG_TEC_CH_B3_C1_L,          /* C1 B7 */
  (word *)GG_TEC_CH_B4_C1_START,         GG_TEC_CH_B4_C1_L,          /* C1 B8 */
  (word *)GG_TEC_CH_B5_C1_START,         GG_TEC_CH_B5_C1_L,
#endif

#ifdef GG_INCLUDE_AER  

  GG_NUM_AER_BUFF,                                             /* AER Buffers */
  0x0000,0x0000,                                                /* C1 B0 */
  0x0000,0x0000,                                                /* C1 B1 */
  0x0000,0x0000,                                                /* C1 B2 */
  0x0000,0x0000,                                                /* C1 B3 */
  0x0000,0x0000,                                                /* C1 B4 */
  0x0000,0x0000,                                                /* C1 B5 */
  0x0000,0x0000,                                                /* C1 B6 */
  0x0000,0x0000,                                                /* C1 B7 */
  0x0000,0x0000,                                                /* C1 B8 */
  0x0000,0x0000,                                                /* C1 B9 */


  GG_NUM_AGC_BUFF,                                             /* AGC Buffers */
  0x0000,0x0000,                                                /* C1 B0 */
#endif
  
  GG_NUM_PIU_BUFF,                                                   /* PIU Buffers */
#ifndef GG_PIU_C1_HEAP_ALLOC
  (word *)GG_PIU_B0_C1_START,         GG_PIU_B0_C1_L,          /* C1 B0 */
  (word *)GG_PIU_B1_C1_START,         GG_PIU_B1_C1_L,          /* C1 B1 */
  (word *)GG_PIU_B2_C1_START,         GG_PIU_B2_C1_L,          /* C1 B2 */
  (word *)GG_PIU_B3_C1_START,         GG_PIU_B3_C1_L,          /* C1 B3 */
#else
  0,0, 0,0, 0,0, 0,0, 
#endif

#ifdef GG_INCLUDE_TDU
  GG_NUM_TDU_BUFF,                                                   /* TDU Buffers */
  (word *)GG_TDU_B0_C1_START,         GG_TDU_B0_C1_L,          /* C1 B0 */
  (word *)GG_TDU_B1_C1_START,         GG_TDU_B1_C1_L,          /* C1 B1 */
  (word *)GG_TDU_B2_C1_START,         GG_TDU_B2_C1_L,          /* C1 B2 */
  (word *)GG_TDU_B3_C1_START,         GG_TDU_B3_C1_L,          /* C1 B3 */
  (word *)GG_TDU_B4_C1_START,         GG_TDU_B4_C1_L,          /* C1 B4 */
#endif

#ifdef GG_TDU_SAVEBUF_EXT
  GG_NUM_TDU_BUFF,                                                   /* TDU Buffers */
  (word *)GG_TDUFAX_B0_C1_START,         GG_TDUFAX_B0_C1_L,   /* C1 B0 */
  (word *)GG_TDUFAX_B1_C1_START,         GG_TDUFAX_B1_C1_L,   /* C1 B1 */
  (word *)GG_TDUFAX_B2_C1_START,         GG_TDUFAX_B2_C1_L,   /* C1 B2 */
  (word *)GG_TDUFAX_B3_C1_START,         GG_TDUFAX_B3_C1_L,   /* C1 B3 */
  (word *)GG_TDUFAX_B4_C1_START,         GG_TDUFAX_B4_C1_L,   /* C1 B4 */
#endif

#ifdef PLR_VOICE_OVERLAY
  GG_NUM_TDU_BUFF,                                                   /* TDU Buffers */
  (word *)GG_TDULITE_B0_C1_START,     GG_TDULITE_B0_C1_L,      /* C1 B0 */
  (word *)GG_TDULITE_B1_C1_START,     GG_TDULITE_B1_C1_L,      /* C1 B1 */
  (word *)GG_TDULITE_B2_C1_START,     GG_TDULITE_B2_C1_L,      /* C1 B2 */
  (word *)GG_TDULITE_B3_C1_START,     GG_TDULITE_B3_C1_L,      /* C1 B3 */
  (word *)GG_TDULITE_B4_C1_START,     GG_TDULITE_B4_C1_L,      /* C1 B4 */
#endif

#if defined(VOICE) || defined(VOICE_FAX)    
  GG_NUM_VPU_BUFF,                                                   /* VPU Buffers */
#ifndef GG_VPU_C1_HEAP_ALLOC
  (word *)GG_VPU_B0_C1_START,         GG_VPU_B0_C1_L,          /* C1 B0 */
  (word *)GG_VPU_B1_C1_START,         GG_VPU_B1_C1_L,          /* C1 B1 */
#else
  0,0, 0,0, 
#endif
#endif

#if defined(VOICE) || defined(VOICE_FAX)    
  GG_NUM_PVP_BUFF,                                                   /* PVP Buffers */
#ifndef GG_PVP_C1_HEAP_ALLOC
  (word *)GG_PVP_B0_C1_START,         GG_PVP_B0_C1_L,          /* C1 B0 */
  (word *)GG_PVP_B1_C1_START,         GG_PVP_B1_C1_L,          /* C1 B1 */
  (word *)GG_PVP_B2_C1_START,         GG_PVP_B2_C1_L,          /* C1 B2 */
  (word *)GG_PVP_B3_C1_START,         GG_PVP_B3_C1_L,          /* C1 B3 */
#else
  0,0, 0,0, 0,0, 0,0, 
#endif
#endif
  
#if defined(VOICE) || defined(VOICE_FAX)    
  GG_NUM_TGU_BUFF,                                             /* TGU Buffers */
#ifndef GG_TGU_C1_HEAP_ALLOC
  (word *)GG_TGU_B0_C1_START,         GG_TGU_B0_C1_L,          /* C1 B0 */
#else
  0,0, 
#endif
#endif
  
#if defined(VOICE) || defined(VOICE_FAX)    
  GG_NUM_CID_BUFF,                                                   /* CID Buffers */
#ifdef GG_INCLUDE_CID
  (word *)GG_CID_B0_C1_START,         GG_CID_B0_C1_L,          /* C1 B0 */
  (word *)GG_CID_B1_C1_START,         GG_CID_B1_C1_L,          /* C1 B1 */
  (word *)GG_CID_B2_C1_START,         GG_CID_B2_C1_L,          /* C1 B2 */
  (word *)GG_CID_B3_C1_START,         GG_CID_B3_C1_L,          /* C1 B3 */
#else
  0,0, 0,0, 0,0, 0,0, 
#endif
#endif

#ifdef GG_INCLUDE_RSU  
  GG_NUM_RSU_BUFF,                                             /* RSU Buffers */
  0x0000,0x0000,                                                /* C1 B0 */
  0x0000,0x0000,                                                /* C1 B1 */
  0x0000,0x0000,                                                /* C1 B2 */
#endif

#if (defined(GG_INCLUDE_AAL1) || defined(GG_INCLUDE_AAL2))  
  GG_NUM_ACU_BUFF,                                                   /* ACU Buffers */

  (word *)GG_ACU_B0_C1_START,         GG_ACU_B0_C1_L,          /* C1 B0 */
#endif



#ifdef GG_INCLUDE_RTP
  GG_NUM_RCU_BUFF,                                                   /* RCU Buffers */

  (word *)GG_RCU_B0_C1_START,         GG_RCU_B0_C1_L,          /* C1 B0 */
  (word *)GG_RCU_B1_C1_START,         GG_RCU_B1_C1_L,          /* C1 B1 */
  (word *)GG_RCU_B2_C1_START,         GG_RCU_B2_C1_L,          /* C1 B2 */
#endif

#if (defined(PLRRED) || defined(PLRFEC))
#ifdef PLR_VOICE_OVERLAY
#if (MAX_RED_LEVEL_TEXT > 0)
  GG_NUM_PLR_BUFF,                                                   /* PLR Buffers */
  (word *)GG_PLR_B0_C1_START,         GG_PLR_B0_C1_L,          /* C1 B0 */
  (word *)GG_PLR_B1_C1_START,         GG_PLR_B1_C1_L,          /* C1 B1 */
  (word *)GG_PLR_B2_C1_START,         GG_PLR_B2_C1_L,          /* C1 B2 */
#ifdef PLR_USE_GMP_SUPPLEMENT
  (word *)GG_PLR_B3_C1_START,         GG_PLR_B3_C1_L,          /* C1 B3 */
#endif
#endif
#if ((MAX_RED_LEVEL_VOICE > 0) || (MAX_FEC_LEVEL_2198 > 0))
  GG_NUM_PLR_BUFF,                                                   /* PLR Buffers */
  (word *)GG_PLRVBD_B0_C1_START,      GG_PLRVBD_B0_C1_L,       /* C1 B0 */
  (word *)GG_PLRVBD_B1_C1_START,      GG_PLRVBD_B1_C1_L,       /* C1 B1 */
  (word *)GG_PLRVBD_B2_C1_START,      GG_PLRVBD_B2_C1_L,       /* C1 B2 */
#ifdef PLR_USE_GMP_SUPPLEMENT
  (word *)GG_PLRVBD_B3_C1_START,      GG_PLRVBD_B3_C1_L,       /* C1 B3 */
#endif
#endif
#if ((MAX_RED_LEVEL_FAX > 0) && defined(GG_INCLUDE_FAX_RELAY))
  GG_NUM_PLR_BUFF,                                                   /* PLR Buffers */
  (word *)GG_PLRFAX_B0_C1_START,      GG_PLRFAX_B0_C1_L,       /* C1 B0 */
  (word *)GG_PLRFAX_B1_C1_START,      GG_PLRFAX_B1_C1_L,       /* C1 B1 */
  (word *)GG_PLRFAX_B2_C1_START,      GG_PLRFAX_B2_C1_L,       /* C1 B2 */
#ifdef PLR_USE_GMP_SUPPLEMENT
  (word *)GG_PLRFAX_B3_C1_START,      GG_PLRFAX_B3_C1_L,       /* C1 B3 */
#endif
#endif
#else /* OVERLAY - none */
  GG_NUM_PLR_BUFF,                                                   /* PLR Buffers */
  (word *)GG_PLR_B0_C1_START,         GG_PLR_B0_C1_L,          /* C1 B0 */
  (word *)GG_PLR_B1_C1_START,         GG_PLR_B1_C1_L,          /* C1 B1 */
  (word *)GG_PLR_B2_C1_START,         GG_PLR_B2_C1_L,          /* C1 B2 */
#ifdef PLR_USE_GMP_SUPPLEMENT
  (word *)GG_PLR_B3_C1_START,         GG_PLR_B3_C1_L,          /* C1 B3 */
#endif
#endif
#endif


#ifdef GG_INCLUDE_MSU
  GG_NUM_MSURTP_BUFF,                                                   /* MSU RTP Buffers */
#ifndef GG_MSU_RTP_C1_HEAP_ALLOC
  (word *)GG_MSU_RTP_B0_C1_START,     GG_MSU_RTP_B0_C1_L,    /* C1 B0 */
#else
  0,0,  
#endif

  GG_NUM_MSURTCP_BUFF,                                              /* MSU RTCP Buffers */
#ifndef GG_MSU_RTCP_C1_HEAP_ALLOC
  (word *)GG_MSU_RTCP_B0_C1_START,    GG_MSU_RTCP_B0_C1_L,   /* C1 B0 */
#else
  0,0,  
#endif
#endif

#ifdef GG_INCLUDE_NET_ENCAP

  GG_NUM_NEU_BUFF,                                                   /* NEU Buffers */
#ifndef GG_NEU_C1_HEAP_ALLOC
  (word *)GG_NEU_B0_C1_START,         GG_NEU_B0_C1_L,          /* C1 B0 */
  (word *)GG_NEU_B1_C1_START,         GG_NEU_B1_C1_L,          /* C1 B1 */
  (word *)GG_NEU_B2_C1_START,         GG_NEU_B2_C1_L,          /* C1 B2 */
  (word *)GG_NEU_B3_C1_START,         GG_NEU_B3_C1_L,          /* C1 B3 */
  (word *)GG_NEU_B4_C1_START,         GG_NEU_B4_C1_L,          /* C1 B4 */
#else
  0,0, 0,0, 0,0, 0,0, 0,0,
#endif
#endif
  
#ifdef GG_INCLUDE_ANNOUNCEMENTS
  GG_NUM_ANU_BUFF,                                             /* NEU Buffers */
#ifndef GG_ANU_C1_HEAP_ALLOC
  (word *)GG_ANU_B0_C1_START,         GG_ANU_B0_C1_L,          /* C1 B0 */
#else
  0,0,
#endif
#endif

#ifdef GG_INCLUDE_PRU
  GG_NUM_PRU_BUFF,                                             /* PRU Buffers */
#ifndef GG_PRU_C1_HEAP_ALLOC
  (word *)GG_PRU_B0_C1_START,         GG_PRU_B0_C1_L,  /* C1 B0 */
#else
  0,0,
#endif
#endif

#ifdef GG_INCLUDE_TTU
  GG_NUM_TTU_BUFF,                                                   /* TTU Buffers */
#ifndef GG_TTU_C1_HEAP_ALLOC
  (word *)GG_TTU_B0_C1_START,         GG_TTU_B0_C1_L,          /* C1 B0 */
#else
  0,0,
#endif
#endif


#ifdef GG_INCLUDE_FAX_RELAY
  
#if defined(FAX) || defined(VOICE_FAX)    
  GG_NUM_FM_BUFF,                                             /* DPU Buffers */
#ifndef GG_FM_C1_HEAP_ALLOC
  (word *)GG_FM_B0_C1_START,          GG_FM_B0_C1_L,           /* C1 B0 */
  (word *)GG_FM_B1_C1_START,          GG_FM_B1_C1_L,           /* C1 B1 */
  (word *)GG_FM_B2_C1_START,          GG_FM_B2_C1_L,           /* C1 B2 */
  (word *)GG_FM_B3_C1_START,          GG_FM_B3_C1_L,           /* C1 B3 */
  (word *)GG_FM_B4_C1_START,          GG_FM_B4_C1_L,           /* C1 B4 */
  (word *)GG_FM_B5_C1_START,          GG_FM_B5_C1_L,           /* C1 B5 */
  (word *)GG_FM_B6_C1_START,          GG_FM_B6_C1_L,           /* C1 B6 */
  (word *)GG_FM_B7_C1_START,          GG_FM_B7_C1_L,           /* C1 B7 */
  (word *)GG_FM_B8_C1_START,          GG_FM_B8_C1_L,           /* C1 B8 */
  (word *)GG_FM_B9_C1_START,          GG_FM_B9_C1_L,           /* C1 B9 */
  (word *)GG_FM_B10_C1_START,         GG_FM_B10_C1_L,          /* C1 B10 */
  (word *)GG_FM_B11_C1_START,         GG_FM_B11_C1_L,          /* C1 B11 */
  (word *)GG_FM_B12_C1_START,         GG_FM_B12_C1_L,          /* C1 B12 */
  (word *)GG_FM_B13_C1_START,         GG_FM_B13_C1_L,          /* C1 B13 */
  (word *)GG_FM_B14_C1_START,         GG_FM_B14_C1_L,          /* C1 B14 */
  (word *)GG_FM_B15_C1_START,         GG_FM_B15_C1_L,          /* C1 B15 */
  (word *)GG_FM_B16_C1_START,         GG_FM_B16_C1_L,          /* C1 B16 */
  (word *)GG_FM_B17_C1_START,         GG_FM_B17_C1_L,          /* C1 B17 */
  (word *)GG_FM_B18_C1_START,         GG_FM_B18_C1_L,          /* C1 B18 */
  (word *)GG_FM_B19_C1_START,         GG_FM_B19_C1_L,          /* C1 B19 */
  (word *)GG_FM_B20_C1_START,         GG_FM_B20_C1_L,          /* C1 B20 */
#else
  0,0, 0,0, 0,0, 0,0, 0,0, 0,0, 0,0, 0,0, 0,0, 0,0,  
  0,0, 0,0, 0,0, 0,0, 0,0, 0,0, 0,0, 0,0, 0,0, 0,0, 0,0, 
#endif
#endif
  
#if defined(FAX) || defined(VOICE_FAX)    
  GG_NUM_FIU_BUFF,                                             /* FIU Buffers */
#ifndef GG_FIU_C1_HEAP_ALLOC
  (word *)GG_FIU_B0_C1_START,         GG_FIU_B0_C1_L,          /* C1 B0 */
  (word *)GG_FIU_B1_C1_START,         GG_FIU_B1_C1_L,          /* C1 B1 */
  (word *)GG_FIU_B2_C1_START,         GG_FIU_B2_C1_L,          /* C1 B2 */
  (word *)GG_FIU_B3_C1_START,         GG_FIU_B3_C1_L,          /* C1 B3 */
  (word *)GG_FIU_B4_C1_START,         GG_FIU_B4_C1_L,          /* C1 B3 */
#else
  0,0, 0,0, 0,0, 0,0,0,0, 
#endif
#endif

#endif /* GG_INCLUDE_FAX_RELAY */


#ifdef GG_INCLUDE_MODEM_RELAY  
  GG_NUM_MRU_BUFF,                                             /* MRU Buffers */
  0x0000,0x0000,                                                /* C1 B0 */
  0x0000,0x0000,                                                /* C1 B1 */
  0x0000,0x0000,                                                /* C1 B2 */
  0x0000,0x0000,                                                /* C1 B3 */
  0x0000,0x0000,                                                /* C1 B4 */
  0x0000,0x0000,                                                /* C1 B5 */
#endif

#ifdef GG_INCLUDE_MDMCP
  GG_NUM_MDMCP_BUFF,                                               /* MDMCP Buffers */
  0,0, 
  0,0, 
#endif

#if defined(GG_INCLUDE_DATA_MODEM) || defined(GG_INCLUDE_LINK_LAYER_MODEM_RELAY)
  GG_NUM_DMP_BUFF,                                                   /* DMP Buffers */
  0,0, 
  0,0, 
  0,0, 
  0,0, 
  0,0, 
  0,0, 
#endif

#if (defined (GG_INCLUDE_CLEAR_DATA) || defined (GG_INCLUDE_FAX_MODEM) || defined (GG_INCLUDE_DATA_MODEM) || defined (AUDIO))
  GG_NUM_MPP_BUFF,                                                   /* MPP Buffers */
#ifndef GG_MPP_C1_HEAP_ALLOC
  (word *)GG_MPP_B0_C1_START,        GG_MPP_B0_C1_L,         /* C1 B0 */
  (word *)GG_MPP_B1_C1_START,        GG_MPP_B1_C1_L,         /* C1 B1 */
  (word *)GG_MPP_B2_C1_START,        GG_MPP_B2_C1_L,         /* C1 B2 */
#else
  0,0, 
  0,0, 
  0,0,  
#endif

#endif

#ifdef GG_INCLUDE_BERT
  GG_NUM_BERT_BUFF,                                                 /* BERT Buffers */
  0,0, 
#endif

#ifdef NX64 
  GG_NUM_NXU_BUFF,                                                    /* NXU Buffers */
#ifndef GG_NXU_C1_HEAP_ALLOC
  (word *)GG_NXU_B0_C1_START,        GG_NXU_B0_C1_L,         /* C1 B0 */
  (word *)GG_NXU_B1_C1_START,        GG_NXU_B1_C1_L,         /* C1 B1 */
#else
  0,0,0,0, 
#endif
#endif

#ifdef EQI 
  GG_NUM_EQI_BUFF,                                                    /* EQI Buffers */
#ifndef GG_EQI_C1_HEAP_ALLOC
  (word *)GG_EQI_B0_C1_START,        GG_EQI_B0_C1_L,         /* C1 B0 */
#else
  0,0, 
#endif
#endif

#ifdef GG_INCLUDE_VQM
  GG_NUM_VQM_BUFF,
  0,0, 
#endif

#ifdef GG_INCLUDE_LINK_LAYER_MODEM_RELAY
  GG_NUM_LLMRU_BUFF,                                               /* LLMRU Buffers */
  0,0, 
  0,0, 
  0,0, 
  0,0, 
  0,0, 
  0,0, 
  0,0, 
  0,0, 
  0,0, 
  0,0, 
  0,0, 
  0,0, 
  0,0, 
  0,0, 
  0,0, 
  0,0, 
  0,0, 
  0,0, 
  0,0,

  GG_NUM_SPRTP_BUFF,                                               /* SPRTP Buffers */
  0,0, 
  0,0, 
#endif

#if defined(VOICE) || defined(VOICE_FAX)    
  GG_NUM_TX_NMU_BUFF,
#ifdef G711A2
  (word *)GG_TX_NMU_B0_C1_START,     GG_TX_NMU_B0_C1_L,      /* C1 B0 */
  (word *)GG_TX_NMU_B1_C1_START,     GG_TX_NMU_B1_C1_L,      /* C1 B1 */
  (word *)GG_TX_NMU_B2_C1_START,     GG_TX_NMU_B2_C1_L,      /* C1 B2 */    
#else
  (word *)GG_TX_NMU_B0_C1_START,     GG_TX_NMU_B0_C1_L,      /* C1 B0 */
#endif
#endif


#if defined(VOICE) || defined(VOICE_FAX)    
  GG_NUM_RX_NMU_BUFF,
#ifdef G711A2
  (word *)GG_RX_NMU_B0_C1_START,     GG_RX_NMU_B0_C1_L,      /* C1 B0 */
  (word *)GG_RX_NMU_B1_C1_START,     GG_RX_NMU_B1_C1_L,      /* C1 B1 */
  (word *)GG_RX_NMU_B2_C1_START,     GG_RX_NMU_B2_C1_L,      /* C1 B2 */    
#else
  (word *)GG_RX_NMU_B0_C1_START,     GG_RX_NMU_B0_C1_L,      /* C1 B0 */
#endif
#endif


#if defined(VOICE) || defined(VOICE_FAX)    
 GG_NUM_PLC_BUFF,
#ifdef G711A1
  (word *)GG_PLC_B0_C1_START,        GG_PLC_B0_C1_L,      /* C1 B0 */
  (word *)GG_PLC_B1_C1_START,        GG_PLC_B1_C1_L,      /* C1 B1 */
  (word *)GG_PLC_B2_C1_START,        GG_PLC_B2_C1_L,      /* C1 B2 */
  (word *)GG_PLC_B3_C1_START,        GG_PLC_B3_C1_L,      /* C1 B3 */
  (word *)GG_PLC_B4_C1_START,        GG_PLC_B4_C1_L,      /* C1 B4 */
#else
  (word *)GG_PLC_B0_C1_START,        GG_PLC_B0_C1_L,      /* C1 B0 */
#endif
#endif


#ifdef GG_MULTSAMPVC
  GG_NUM_MULTSAMPVC_BUFF,
  0,0,
  0,0,
  0,0, 
  0,0, 
  0,0,
#endif

#ifdef VEU
  GG_NUM_VEU_BUFF,
#ifndef GG_VEU_C1_HEAP_ALLOC
  (word *)GG_VEU_B0_C1_START,         GG_VEU_B0_L,          /* C1 B0 */  
#else
  0,0,
#endif
#endif

#ifdef AUDIO
  GG_NUM_ADU_BUFF,                                                   /* PIU Buffers */
#ifndef GG_ADU_C1_HEAP_ALLOC
  (word *)GG_ADU_B0_C1_START,         GG_ADU_B0_C1_L,          /* C1 B0 */
  (word *)GG_ADU_B1_C1_START,         GG_ADU_B1_C1_L,          /* C1 B1 */
  (word *)GG_ADU_B2_C1_START,         GG_ADU_B2_C1_L,          /* C1 B2 */
  (word *)GG_ADU_B3_C1_START,         GG_ADU_B3_C1_L,          /* C1 B3 */
  (word *)GG_ADU_B4_C1_START,         GG_ADU_B4_C1_L,          /* C1 B4 */
  (word *)GG_ADU_B5_C1_START,         GG_ADU_B5_C1_L,          /* C1 B5 */
  (word *)GG_ADU_B6_C1_START,         GG_ADU_B6_C1_L,          /* C1 B6 */
  (word *)GG_ADU_B7_C1_START,         GG_ADU_B7_C1_L,          /* C1 B7 */
#else
  0,0, 0,0, 0,0, 0,0, 0,0, 0,0, 0,0, 0,0,
#endif
#endif

#ifdef NX64 
  GG_NUM_NPIU_BUFF,                                                  /* NPIU Buffers */
#ifndef GG_NPIU_C1_HEAP_ALLOC
  (word *)GG_NPIU_B0_C1_START,        GG_NPIU_B0_C1_L,       /* C1 B0 */
  (word *)GG_NPIU_B1_C1_START,        GG_NPIU_B1_C1_L,       /* C1 B1 */
  (word *)GG_NPIU_B2_C1_START,        GG_NPIU_B2_C1_L,       /* C1 B2 */
#else
  0,0,0,0,0,0, 
#endif
#endif

#ifdef HDVIDEO
  GG_NUM_VTK_BUFF,                                                  /* VTK Buffers */
#ifndef GG_VTK_C1_HEAP_ALLOC
  (word *)GG_VTK_B0_C1_START,        GG_VTK_B0_C1_L,        /* C1 B0 */
#else
  0,0,
#endif

  GG_NUM_ATK_BUFF,                                                  /* ATK Buffers */
#ifndef GG_ATK_C1_HEAP_ALLOC
  (word *)GG_ATK_B0_C1_START,        GG_ATK_B0_C1_L,        /* C1 B0 */
  (word *)GG_ATK_B1_C1_START,        GG_ATK_B1_C1_L,        /* C1 B1 */
#else
  0,0,0,0,
#endif


  GG_NUM_TSU_BUFF,                                                  /* TSU Buffers */
#ifndef GG_TSU_C1_HEAP_ALLOC
  (word *)GG_TSU_B0_C1_START,        GG_TSU_B0_C1_L,        /* C1 B0 */
  (word *)GG_TSU_B1_C1_START,        GG_TSU_B1_C1_L,        /* C1 B1 */
#else
  0,0,0,0,
#endif

/*=======================================================================*/
/* Video Build: customEco buffers here                                   */
/*=======================================================================*/
  GG_NUM_CUSTOM_ECO_BUFF,                                           /* CUSTOM_ECO Buffers */
#ifndef GG_CUSTOM_ECO_C1_HEAP_ALLOC
  (word *)GG_CUSTOM_ECO_B0_C1_START,        GG_CUSTOM_ECO_B0_C1_L,  /* C1 B0 */
#else
  0,0,
#endif
/*=======================================================================*/
/* Video Build: customEco buffers, unitl here                            */
/*=======================================================================*/

  GG_NUM_OVLY_BUFF,                                           /* OVLY Buffers */
#ifndef GG_OVLY_C1_HEAP_ALLOC
  (word *)GG_OVLY_B0_C1_START,        GG_OVLY_B0_C1_L,  /* C1 B0 */
#else
  0,0,
#endif

  GG_NUM_MMCU_BUFF,                                           /* MMCU Buffers */
#ifndef GG_MMCU_C1_HEAP_ALLOC
  (word *)GG_MMCU_B0_C1_START,        GG_MMCU_B0_C1_L,  /* C1 B0 */
  (word *)GG_MMCU_B1_C1_START,        GG_MMCU_B1_C1_L,  /* C1 B1 */  
#else
  0,0,0,0,
#endif
#endif

#if defined(HDCT) || defined(HDVIDEO) 
  GG_NUM_VPPU_BUFF,                                                  /* VPPU Buffers */
#ifndef GG_VPPU_C1_HEAP_ALLOC
  (word *)GG_VPPU_B0_C1_START,        GG_VPPU_B0_C1_L,       /* C1 B0 */
  (word *)GG_VPPU_B1_C1_START,        GG_VPPU_B1_C1_L,       /* C1 B1 */
  (word *)GG_VPPU_B2_C1_START,        GG_VPPU_B2_C1_L,       /* C1 B2 */
#else
  0,0,0,0,0,0,
#endif
  GG_NUM_TFTP_BUFF,                                           /* TFTP Buffers */
#ifndef GG_TFTP_C1_HEAP_ALLOC
  (word *)GG_TFTP_B0_C1_START,        GG_TFTP_B0_C1_L,  /* C1 B0 */
#else
  0,0,
#endif
#endif

  /* End expansion $ch = 1 */
/* Expanding $ch = 2 */

  /*=======================================================================*/
  /* Channel 2 */
  /*=======================================================================*/
#ifdef GG_INCLUDE_PCM
  GG_NUM_ENC_PCM_BUFF,                                    /* VCA Buffers */

  (word *)GG_PCM_ENC_B0_C2_START,     GG_PCM_ENC_B0_C2_L,      /* C2 B0 */
#endif

#ifdef GG_INCLUDE_G726

  GG_NUM_ENC_ADPCM_BUFF,                                 /* ADPCM Buffers */
  (word *)GG_ADPCM_ENC_B0_C2_START,   GG_ADPCM_ENC_B0_C2_L,    /* C2 B0 */  
  (word *)GG_ADPCM_ENC_B1_C2_START,   GG_ADPCM_ENC_B1_C2_L,    /* C2 B1 */
  (word *)GG_ADPCM_ENC_B2_C2_START,   GG_ADPCM_ENC_B2_C2_L,    /* C2 B1 */
#endif
  
#ifdef GG_INCLUDE_G729AB

  GG_NUM_ENC_G729AB_BUFF,                                    /* G729AB Buffers */

  (word *)GG_G729AB_ENC_B0_C2_START,  GG_G729AB_ENC_B0_C2_L,   /* C2 B0 */    
  (word *)GG_G729AB_ENC_B1_C2_START,  GG_G729AB_ENC_B1_C2_L,   /* C2 B1 */    
  (word *)GG_G729AB_ENC_B2_C2_START,  GG_G729AB_ENC_B2_C2_L,   /* C2 B2 */    
  (word *)GG_G729AB_ENC_B3_C2_START,  GG_G729AB_ENC_B3_C2_L,   /* C2 B3 */    
  (word *)GG_G729AB_ENC_B4_C2_START,  GG_G729AB_ENC_B4_C2_L,   /* C2 B4 */    
  (word *)GG_G729AB_ENC_B5_C2_START,  GG_G729AB_ENC_B5_C2_L,   /* C2 B5 */    
  (word *)GG_G729AB_ENC_B6_C2_START,  GG_G729AB_ENC_B6_C2_L,   /* C2 B6 */    
  (word *)GG_G729AB_ENC_B7_C2_START,  GG_G729AB_ENC_B7_C2_L,   /* C2 B7 */    
  (word *)GG_G729AB_ENC_B8_C2_START,  GG_G729AB_ENC_B8_C2_L,   /* C2 B8 */
  0x0000,0x0000,
  0x0000,0x0000,
  0x0000,0x0000,
#endif

#ifdef GG_INCLUDE_G729    

  GG_NUM_ENC_G729_BUFF,                                        /* G729 Buffers  */
  0x0000,0x0000,                                                /* C2 B0 */
  0x0000,0x0000,                                                /* C2 B1 */
  0x0000,0x0000,                                                /* C2 B2 */
  0x0000,0x0000,                                                /* C2 B3 */
  0x0000,0x0000,                                                /* C2 B4 */
  0x0000,0x0000,                                                /* C2 B5 */
#endif
  
#ifdef GG_INCLUDE_G729E    
  GG_NUM_ENC_G729E_BUFF,                                       /* G729E Buffers */
  0x0000,0x0000,                                                /* C2 B0 */
  0x0000,0x0000,                                                /* C2 B1 */
  0x0000,0x0000,                                                /* C2 B2 */
  0x0000,0x0000,                                                /* C2 B3 */
  0x0000,0x0000,                                                /* C2 B4 */
  0x0000,0x0000,                                                /* C2 B5 */
  0x0000,0x0000,                                                /* C2 B6 */
  0x0000,0x0000,                                                /* C2 B7 */
  0x0000,0x0000,                                                /* C2 B8 */
  0x0000,0x0000,                                                /* C2 B9 */
  0x0000,0x0000,                                                /* C2 B10 */
  0x0000,0x0000,                                                /* C2 B11 */
#endif

#ifdef GG_INCLUDE_G723    
  GG_NUM_ENC_G723_BUFF,                                        /* G723 Buffers */
  (word *)GG_G723_ENC_B0_C2_START,    GG_G723_ENC_B0_C2_L,     /* C2 B0 */
  (word *)GG_G723_ENC_B1_C2_START,    GG_G723_ENC_B1_C2_L,     /* C2 B1 */
  (word *)GG_G723_ENC_B2_C2_START,    GG_G723_ENC_B2_C2_L,     /* C2 B2 */
  (word *)GG_G723_ENC_B3_C2_START,    GG_G723_ENC_B3_C2_L,     /* C2 B3 */
  (word *)GG_G723_ENC_B4_C2_START,    GG_G723_ENC_B4_C2_L,     /* C2 B4 */
  (word *)GG_G723_ENC_B5_C2_START,    GG_G723_ENC_B5_C2_L,     /* C2 B5 */
#endif
  
#ifdef GG_INCLUDE_G728    
  GG_NUM_ENC_G728_BUFF,                                        /* G728 Buffers  */
  0x0000,0x0000,                                                /* C2 B0 */
  0x0000,0x0000,                                                /* C2 B1 */
  0x0000,0x0000,                                                /* C2 B2 */
  0x0000,0x0000,                                                /* C2 B3 */
  0x0000,0x0000,                                                /* C2 B4 */
  0x0000,0x0000,                                                /* C2 B5 */
  0x0000,0x0000,                                                /* C2 B6 */
#endif

#ifdef GG_INCLUDE_GSMEFR  
  GG_NUM_ENC_GSMEFR_BUFF,                                  /* GSM EFR Buffers */
  0x0000,0x0000,                                                /* C2 B0  */
  0x0000,0x0000,                                                /* C2 B1  */
  0x0000,0x0000,                                                /* C2 B2  */
  0x0000,0x0000,                                                /* C2 B3  */
  0x0000,0x0000,                                                /* C2 B4  */
  0x0000,0x0000,                                                /* C2 B5  */
  0x0000,0x0000,                                                /* C2 B6  */
#endif
  
#ifdef GG_INCLUDE_GSMFR  
  GG_NUM_ENC_GSMFR_BUFF,                                  /* GSM FR Buffers */
  (word *) GG_GSMFR_ENC_B0_C2_START, GG_GSMFR_ENC_B0_C2_L, /* C2 B0 */
  (word *) GG_GSMFR_ENC_B1_C2_START, GG_GSMFR_ENC_B1_C2_L, /* C2 B1 */
  (word *) GG_GSMFR_ENC_B2_C2_START, GG_GSMFR_ENC_B2_C2_L, /* C2 B2 */
  0x0000,0x0000,                                                   /* C2 B3 */
#endif
  
#ifdef GG_INCLUDE_G722 
  GG_NUM_ENC_G722_BUFF,                                        /* G722 Buffers */
  0x0000,0x0000,                                                /* C2 B0 */
  0x0000,0x0000,                                                /* C2 B1 */ 
  0x0000,0x0000,                                                /* C2 B2 */
  0x0000,0x0000,                                                /* C2 B3 */
  0x0000,0x0000,                                                /* C2 B4 */
#endif

#ifdef GG_INCLUDE_ILBC  
  GG_NUM_ENC_ILBC_BUFF,

  (word *)GG_ILBC_ENC_B0_C2_START,   GG_ILBC_ENC_B0_C2_L,    /* C1 B0 */
  (word *)GG_ILBC_ENC_B1_C2_START,   GG_ILBC_ENC_B1_C2_L,    /* C1 B1 */
  (word *)GG_ILBC_ENC_B2_C2_START,   GG_ILBC_ENC_B2_C2_L,    /* C1 B2 */
  (word *)0,0,
#endif



#ifdef GG_INCLUDE_GSMAMR                                      
  GG_NUM_ENC_GSMAMR_BUFF,                                              /* GSMAMR Buffers*/

  (word *)GG_GSMAMR_ENC_B0_C2_START,    GG_GSMAMR_ENC_B0_C2_L,     /* C2 B0 */
  (word *)GG_GSMAMR_ENC_B1_C2_START,    GG_GSMAMR_ENC_B1_C2_L,     /* C2 B1 */
  (word *)GG_GSMAMR_ENC_B2_C2_START,    GG_GSMAMR_ENC_B2_C2_L,     /* C2 B2 */
  (word *)GG_GSMAMR_ENC_B3_C2_START,    GG_GSMAMR_ENC_B3_C2_L,     /* C2 B3 */
  (word *)GG_GSMAMR_ENC_B4_C2_START,    GG_GSMAMR_ENC_B4_C2_L,     /* C2 B4 */
  (word *)GG_GSMAMR_ENC_B5_C2_START,    GG_GSMAMR_ENC_B5_C2_L,     /* C2 B5 */
  (word *)GG_GSMAMR_ENC_B6_C2_START,    GG_GSMAMR_ENC_B6_C2_L,     /* C2 B6 */
  (word *)GG_GSMAMR_ENC_B7_C2_START,    GG_GSMAMR_ENC_B7_C2_L,     /* C2 B7 */
  (word *)GG_GSMAMR_ENC_B8_C2_START,    GG_GSMAMR_ENC_B8_C2_L,     /* C2 B8 */
  (word *)GG_GSMAMR_ENC_B9_C2_START,    GG_GSMAMR_ENC_B9_C2_L,     /* C2 B9 */
#endif

#ifdef GG_INCLUDE_GG_INCLUDE_G722_2                                      
  GG_NUM_ENC_GSM_WBAMR_BUFF,                                              /* GSM_WBAMR Buffers*/
  (word *)GG_GSM_WBAMR_ENC_B0_C2_START,    GG_GSM_WBAMR_ENC_B0_C2_L,     /* C2 B0 */
  (word *)GG_GSM_WBAMR_ENC_B1_C2_START,    GG_GSM_WBAMR_ENC_B1_C2_L,     /* C2 B1 */
  (word *)GG_GSM_WBAMR_ENC_B2_C2_START,    GG_GSM_WBAMR_ENC_B2_C2_L,     /* C2 B2 */
  (word *)GG_GSM_WBAMR_ENC_B3_C2_START,    GG_GSM_WBAMR_ENC_B3_C2_L,     /* C2 B3 */
  (word *)GG_GSM_WBAMR_ENC_B4_C2_START,    GG_GSM_WBAMR_ENC_B4_C2_L,     /* C2 B4 */
  (word *)GG_GSM_WBAMR_ENC_B5_C2_START,    GG_GSM_WBAMR_ENC_B5_C2_L,     /* C2 B5 */
#endif


#ifdef GG_INCLUDE_EVRC
  GG_NUM_ENC_EVRC_BUFF,                                        /* EVRC/EVRC Buffers */   
  (word *)GG_EVRC_ENC_B0_C2_START,  GG_EVRC_ENC_B0_C2_L,   /* C2 B0 */
  (word *)GG_EVRC_ENC_B1_C2_START,  GG_EVRC_ENC_B1_C2_L,   /* C2 B1 */
  (word *)GG_EVRC_ENC_B2_C2_START,  GG_EVRC_ENC_B2_C2_L,   /* C2 B2 */
  (word *)GG_EVRC_ENC_B3_C2_START,  GG_EVRC_ENC_B3_C2_L,   /* C2 B3 */
  (word *)GG_EVRC_ENC_B4_C2_START,  GG_EVRC_ENC_B4_C2_L,   /* C2 B4 */
  (word *)GG_EVRC_ENC_B5_C2_START,  GG_EVRC_ENC_B5_C2_L,   /* C2 B5 */
  (word *)GG_EVRC_ENC_B6_C2_START,  GG_EVRC_ENC_B6_C2_L,   /* C2 B6 */
#endif

#ifdef GG_INCLUDE_SMV                                       
  GG_NUM_ENC_SMV_BUFF,                                         /* SMV */ 
  (word *)GG_SMV_ENC_B0_C2_START,  GG_SMV_ENC_B0_C2_L,   /* C2 B0 */
  (word *)GG_SMV_ENC_B1_C2_START,  GG_SMV_ENC_B1_C2_L,   /* C2 B1 */
  (word *)GG_SMV_ENC_B2_C2_START,  GG_SMV_ENC_B2_C2_L,   /* C2 B2 */
  (word *)0,0,
#endif
#ifdef GG_INCLUDE_QCELP13
 GG_NUM_ENC_QCELP13_BUFF,                                         /* QCELP13 Buffers   */
  (word *)GG_QCELP13_ENC_B0_C2_START,  GG_QCELP13_ENC_B0_C2_L,   /* C2 B0  */
  (word *)GG_QCELP13_ENC_B1_C2_START,  GG_QCELP13_ENC_B1_C2_L,   /* C2 B1   */
  (word *)GG_QCELP13_ENC_B2_C2_START,  GG_QCELP13_ENC_B2_C2_L,   /* C2 B2   */
  (word *)GG_QCELP13_ENC_B3_C2_START,  GG_QCELP13_ENC_B3_C2_L,   /* C2 B3  */
  (word *)GG_QCELP13_ENC_B4_C2_START,  GG_QCELP13_ENC_B4_C2_L,   /* C2 B4   */
  (word *)GG_QCELP13_ENC_B5_C2_START,  GG_QCELP13_ENC_B5_C2_L,   /* C2 B5   */
  (word *)GG_QCELP13_ENC_B6_C2_START,  GG_QCELP13_ENC_B6_C2_L,   /* C2 B6   */
  (word *)GG_QCELP13_ENC_B7_C2_START,  GG_QCELP13_ENC_B7_C2_L,   /* C2 B7   */
  (word *)GG_QCELP13_ENC_B8_C2_START,  GG_QCELP13_ENC_B8_C2_L,   /* C2 B8   */
#endif																	

#ifdef AUDIO
 #ifdef GG_INCLUDE_MP3
  GG_NUM_DEC_MP3_BUFF,                                                  /* MP3 No Encoder*/
  (word *)0,0,(word *)0,0, (word *)0,0, (word *)0,0,
  (word *)0,0,(word *)0,0, (word *)0,0, (word *)0,0,
  (word *)0,0,
 #endif
#endif

#ifdef GG_INCLUDE_PCM                                      
  GG_NUM_DEC_PCM_BUFF,                                        /* VCA Buffers */

  (word *)GG_PCM_DEC_B0_C2_START,     GG_PCM_DEC_B0_C2_L,      /* C2 B0 */
#endif

#ifdef GG_INCLUDE_G726

  GG_NUM_DEC_ADPCM_BUFF,                                    /* ADPCM Buffers */
  (word *)GG_ADPCM_DEC_B0_C2_START,   GG_ADPCM_DEC_B0_C2_L,    /* C2 B0 */  
  (word *)GG_ADPCM_DEC_B1_C2_START,   GG_ADPCM_DEC_B1_C2_L,    /* C2 B1 */
  (word *)GG_ADPCM_DEC_B2_C2_START,   GG_ADPCM_DEC_B2_C2_L,    /* C2 B1 */
#endif

#ifdef GG_INCLUDE_G729AB  

  GG_NUM_DEC_G729AB_BUFF,                                   /* G729AB Buffers */

  (word *)GG_G729AB_DEC_B0_C2_START,  GG_G729AB_DEC_B0_C2_L,   /* C2 B0 */    
  (word *)GG_G729AB_DEC_B1_C2_START,  GG_G729AB_DEC_B1_C2_L,   /* C2 B1 */    
  (word *)GG_G729AB_DEC_B2_C2_START,  GG_G729AB_DEC_B2_C2_L,   /* C2 B2 */    
  (word *)GG_G729AB_DEC_B3_C2_START,  GG_G729AB_DEC_B3_C2_L,   /* C2 B3 */    
  (word *)GG_G729AB_DEC_B4_C2_START,  GG_G729AB_DEC_B4_C2_L,   /* C2 B4 */    
  (word *)GG_G729AB_DEC_B5_C2_START,  GG_G729AB_DEC_B5_C2_L,   /* C2 B5 */    
  (word *)GG_G729AB_DEC_B6_C2_START,  GG_G729AB_DEC_B6_C2_L,   /* C2 B6 */    
  (word *)GG_G729AB_DEC_B7_C2_START,  GG_G729AB_DEC_B7_C2_L,   /* C2 B7 */    
  (word *)GG_G729AB_DEC_B8_C2_START,  GG_G729AB_DEC_B8_C2_L,   /* C2 B8 */    
  (word *)GG_G729AB_DEC_B9_C2_START,  GG_G729AB_DEC_B9_C2_L,   /* C2 B9 */    
  (word *)GG_G729AB_DEC_B10_C2_START, GG_G729AB_DEC_B10_C2_L,   /* C2 B10 */
  (word *)GG_G729AB_DEC_B11_C2_START, GG_G729AB_DEC_B11_C2_L,   /* C2 B11 */
#endif  
 
#ifdef GG_INCLUDE_G729  
  GG_NUM_DEC_G729_BUFF,                                        /* G729 Buffers */
  0x0000,0x0000,                                                /* C2 B0 */
  0x0000,0x0000,                                                /* C2 B1 */
  0x0000,0x0000,                                                /* C2 B2 */
  0x0000,0x0000,                                                /* C2 B3 */
  0x0000,0x0000,                                                /* C2 B4 */
  0x0000,0x0000,                                                /* C2 B5 */
#endif  

#ifdef GG_INCLUDE_G729E 
  GG_NUM_DEC_G729E_BUFF,                                       /* G729E Buffers */
  0x0000,0x0000,                                                /* C2 B0 */
  0x0000,0x0000,                                                /* C2 B1 */
  0x0000,0x0000,                                                /* C2 B2 */
  0x0000,0x0000,                                                /* C2 B3 */
  0x0000,0x0000,                                                /* C2 B4 */
  0x0000,0x0000,                                                /* C2 B5 */
  0x0000,0x0000,                                                /* C2 B6 */
  0x0000,0x0000,                                                /* C2 B7 */
  0x0000,0x0000,                                                /* C2 B8 */
  0x0000,0x0000,                                                /* C2 B9 */
  0x0000,0x0000,                                                /* C2 B10 */
  0x0000,0x0000,                                                /* C2 B11 */
#endif

#ifdef GG_INCLUDE_G723
  GG_NUM_DEC_G723_BUFF,                                        /* G723 Buffers */
  (word *)GG_G723_DEC_B0_C2_START,    GG_G723_DEC_B0_C2_L,     /* C2 B0 */
  (word *)GG_G723_DEC_B1_C2_START,    GG_G723_DEC_B1_C2_L,     /* C2 B1 */
  (word *)GG_G723_DEC_B2_C2_START,    GG_G723_DEC_B2_C2_L,     /* C2 B2 */
  (word *)GG_G723_DEC_B3_C2_START,    GG_G723_DEC_B3_C2_L,     /* C2 B3 */
  0x0000,0x0000, /* To match Encoder Buffers */                        /* C2 B5 */
  0x0000,0x0000, /* To match Encoder Buffers */                        /* C2 B5 */
#endif

#ifdef GG_INCLUDE_G728
  GG_NUM_DEC_G728_BUFF,                                        /* G728 Buffers */
  0x0000,0x0000,                                                /* C2 B0 */
  0x0000,0x0000,                                                /* C2 B1 */
  0x0000,0x0000,                                                /* C2 B2 */
  0x0000,0x0000,                                                /* C2 B3 */
  0x0000,0x0000,                                                /* C2 B4 */
  0x0000,0x0000,                                                /* C2 B5 */
  0x0000,0x0000,                                                /* C2 B6 */
#endif
  
#ifdef GG_INCLUDE_GSMEFR
  GG_NUM_DEC_GSMEFR_BUFF,                                  /* GSM EFR Buffers */
  0x0000,0x0000,                                                /* C2 B0  */
  0x0000,0x0000,                                                /* C2 B1  */
  0x0000,0x0000,                                                /* C2 B2  */
  0x0000,0x0000,                                                /* C2 B3  */
  0x0000,0x0000,                                                /* C2 B4  */
  0x0000,0x0000,                                                /* C2 B5  */
  0x0000,0x0000,                                                /* C2 B6  */
#endif

#ifdef GG_INCLUDE_GSMFR  
  GG_NUM_DEC_GSMFR_BUFF,                                   /* GSM FR Buffers */
  (word *) GG_GSMFR_DEC_B0_C2_START, GG_GSMFR_DEC_B0_C2_L, /* C2 B0 */
  (word *) GG_GSMFR_DEC_B1_C2_START, GG_GSMFR_DEC_B1_C2_L, /* C2 B1 */
  (word *) GG_GSMFR_DEC_B2_C2_START, GG_GSMFR_DEC_B2_C2_L, /* C2 B2 */
  (word *) GG_GSMFR_DEC_B3_C2_START, GG_GSMFR_DEC_B3_C2_L, /* C2 B3 */
#endif


#ifdef GG_INCLUDE_G722 
  GG_NUM_DEC_G722_BUFF,                                        /* G722 Buffers*/
  0x0000,0x0000,                                                /* C2 B0 */
  0x0000,0x0000,                                                /* C2 B1 */
  0x0000,0x0000,                                                /* C2 B2 */
  0x0000,0x0000,                                                /* C2 B3 */
  0x0000,0x0000,                                                /* C2 B4 */
#endif

#ifdef GG_INCLUDE_ILBC
  GG_NUM_DEC_ILBC_BUFF,

  (word *)GG_ILBC_DEC_B0_C2_START,   GG_ILBC_DEC_B0_C2_L,    /* C1 B0 */
  (word *)GG_ILBC_DEC_B1_C2_START,   GG_ILBC_DEC_B1_C2_L,    /* C1 B1 */
  (word *)GG_ILBC_DEC_B2_C2_START,   GG_ILBC_DEC_B2_C2_L,    /* C1 B1 */
  (word *)GG_ILBC_DEC_B3_C2_START,   GG_ILBC_DEC_B3_C2_L,    /* C1 B1 */
#endif



#ifdef GG_INCLUDE_GSMAMR
  GG_NUM_DEC_GSMAMR_BUFF,                                              /* GSMAMR Buffers*/

  (word *)GG_GSMAMR_DEC_B0_C2_START,    GG_GSMAMR_DEC_B0_C2_L,     /* C2 B0 */
  (word *)GG_GSMAMR_DEC_B1_C2_START,    GG_GSMAMR_DEC_B1_C2_L,     /* C2 B1 */
  (word *)GG_GSMAMR_DEC_B2_C2_START,    GG_GSMAMR_DEC_B2_C2_L,     /* C2 B2 */
  (word *)GG_GSMAMR_DEC_B3_C2_START,    GG_GSMAMR_DEC_B3_C2_L,     /* C2 B3 */
  (word *)GG_GSMAMR_DEC_B4_C2_START,    GG_GSMAMR_DEC_B4_C2_L,     /* C2 B3 */
  (word *)0,0,
  (word *)0,0,
  (word *)0,0,
  (word *)0,0,
  (word *)0,0,
#endif


#ifdef GG_INCLUDE_G722_2
  GG_NUM_DEC_GSM_WBAMR_BUFF,                                              /* GSM_WBAMR Buffers*/

  (word *)GG_GSM_WBAMR_DEC_B0_C2_START,    GG_GSM_WBAMR_DEC_B0_C2_L,     /* C2 B0 */
  (word *)GG_GSM_WBAMR_DEC_B1_C2_START,    GG_GSM_WBAMR_DEC_B1_C2_L,     /* C2 B1 */
  (word *)GG_GSM_WBAMR_DEC_B2_C2_START,    GG_GSM_WBAMR_DEC_B2_C2_L,     /* C2 B2 */
  (word *)GG_GSM_WBAMR_DEC_B3_C2_START,    GG_GSM_WBAMR_DEC_B3_C2_L,     /* C2 B3 */
  (word *)GG_GSM_WBAMR_DEC_B4_C2_START,    GG_GSM_WBAMR_DEC_B4_C2_L,     /* C2 B4 */
  (word *)GG_GSM_WBAMR_DEC_B5_C2_START,    GG_GSM_WBAMR_DEC_B5_C2_L,     /* C2 B5 */  


#endif


#ifdef GG_INCLUDE_EVRC                                       
  GG_NUM_DEC_EVRC_BUFF,                                         /* EVRC/EVRC Buffers */   
  (word *)GG_EVRC_DEC_B0_C2_START,  GG_EVRC_DEC_B0_C2_L,   /* C2 B0 */
  (word *)GG_EVRC_DEC_B1_C2_START,  GG_EVRC_DEC_B1_C2_L,   /* C2 B1 */
  (word *)GG_EVRC_DEC_B2_C2_START,  GG_EVRC_DEC_B2_C2_L,   /* C2 B2 */
  (word *)GG_EVRC_DEC_B3_C2_START,  GG_EVRC_DEC_B3_C2_L,   /* C2 B2 */
  0, 0,	0, 0, 0, 0, 
#endif

#ifdef GG_INCLUDE_SMV                                       
  GG_NUM_DEC_SMV_BUFF,
  (word *)GG_SMV_DEC_B0_C2_START,  GG_SMV_DEC_B0_C2_L,   /* C2 B0 */
  (word *)GG_SMV_DEC_B1_C2_START,  GG_SMV_DEC_B1_C2_L,   /* C2 B1 */
  (word *)GG_SMV_DEC_B2_C2_START,  GG_SMV_DEC_B2_C2_L,   /* C2 B2 */
  (word *)GG_SMV_DEC_B3_C2_START,  GG_SMV_DEC_B3_C2_L,   /* C2 B3 */
#endif

#ifdef GG_INCLUDE_QCELP13
  GG_NUM_DEC_QCELP13_BUFF,                                         /* QCELP13 Buffers */   	
  (word *)GG_QCELP13_DEC_B0_C2_START,  GG_QCELP13_DEC_B0_C2_L,   /* C2 B0 */	
  (word *)GG_QCELP13_DEC_B1_C2_START,  GG_QCELP13_DEC_B1_C2_L,   /* C2 B1 */	
  (word *)GG_QCELP13_DEC_B2_C2_START,  GG_QCELP13_DEC_B2_C2_L,   /* C2 B2 */	
  (word *)GG_QCELP13_DEC_B3_C2_START,  GG_QCELP13_DEC_B3_C2_L,   /* C2 B3 */	
  (word *)GG_QCELP13_DEC_B4_C2_START,  GG_QCELP13_DEC_B4_C2_L,   /* C2 B4 */	
  0, 0,	0, 0, 0, 0, 0, 0,																				
#endif																	

#ifdef AUDIO
 #ifdef GG_INCLUDE_MP3
  GG_NUM_DEC_MP3_BUFF,                                                /* MP3 Buffers*/
  (word *)GG_MP3_DEC_B0_C2_START,    GG_MP3_DEC_B0_C2_L,     /* C2 B0 */
  (word *)GG_MP3_DEC_B1_C2_START,    GG_MP3_DEC_B1_C2_L,     /* C2 B1 */
  (word *)GG_MP3_DEC_B2_C2_START,    GG_MP3_DEC_B2_C2_L,     /* C2 B2 */
  (word *)GG_MP3_DEC_B3_C2_START,    GG_MP3_DEC_B3_C2_L,     /* C2 B3 */
  (word *)GG_MP3_DEC_B4_C2_START,    GG_MP3_DEC_B4_C2_L,     /* C2 B4 */
  (word *)GG_MP3_DEC_B5_C2_START,    GG_MP3_DEC_B5_C2_L,     /* C2 B5 */
  (word *)GG_MP3_DEC_B6_C2_START,    GG_MP3_DEC_B6_C2_L,     /* C2 B6 */
  (word *)GG_MP3_DEC_B7_C2_START,    GG_MP3_DEC_B7_C2_L,     /* C2 B7 */
  (word *)GG_MP3_DEC_B8_C2_START,    GG_MP3_DEC_B8_C2_L,     /* C2 B7 */
 #endif
#endif

#if defined(VOICE) || defined(VOICE_FAX)    
  GG_NUM_VCU_BUFF,                                             /* VCU Buffers */
#ifndef GG_VCU_C2_HEAP_ALLOC
  (word *)GG_VCU_B0_C2_START,         GG_VCU_B0_C2_L,          /* C2 B0 */
  #if (defined(GG_TFO_IPE) || defined(GG_TFO_AE))
  (word *)GG_VCU_B1_C2_START,         GG_VCU_B1_C2_L,          /* C2 B1 */
  #endif
#else
  0,0, 
  #if (defined(GG_TFO_IPE) || defined(GG_TFO_AE))
  0,0,          
  #endif
#endif
#endif

#if defined(VOICE) || defined(VOICE_FAX)    
  GG_NUM_VAU_BUFF,                                                   /* VAU Buffers */
#ifndef GG_VAU_C2_HEAP_ALLOC
  (word *)GG_VAU_B0_C2_START,         GG_VAU_B0_C2_L,          /* C2 B0 */
  (word *)GG_VAU_B1_C2_START,         GG_VAU_B1_C2_L,          /* C2 B1 */
  (word *)GG_VAU_B2_C2_START,         GG_VAU_B2_C2_L,          /* C2 B2 */
#else
  0,0, 0,0, 0,0,  
#endif
#endif

#ifdef GG_INCLUDE_ECU
  GG_NUM_ECU_BUFF,                                                   /* ECU Buffers */

  (word *)GG_ECU_B0_C2_START,         GG_ECU_B0_C2_L,          /* C2 B0 */
  (word *)GG_ECU_B1_C2_START,         GG_ECU_B1_C2_L,          /* C2 B1 */
  (word *)GG_ECU_B2_C2_START,         GG_ECU_B2_C2_L,          /* C2 B2 */
  (word *)GG_ECU_B3_C2_START,         GG_ECU_B3_C2_L,          /* C2 B3 */
  (word *)GG_ECU_B4_C2_START,         GG_ECU_B4_C2_L,          /* C2 B4 */
  (word *)GG_ECU_B5_C2_START,         GG_ECU_B5_C2_L,          /* C2 B5 */
  (word *)GG_ECU_B6_C2_START,         GG_ECU_B6_C2_L,          /* C2 B6 */
  (word *)GG_ECU_B7_C2_START,         GG_ECU_B7_C2_L,          /* C2 B7 */
  (word *)GG_ECU_B8_C2_START,         GG_ECU_B8_C2_L,          /* C2 B8 */
  (word *)GG_ECU_B9_C2_START,         GG_ECU_B9_C2_L,          /* C2 B9 */
  (word *)GG_ECU_B10_C2_START,        GG_ECU_B10_C2_L,         /* C2 B10 */
  (word *)GG_ECU_B11_C2_START,        GG_ECU_B11_C2_L,         /* C2 B11 */
  (word *)GG_ECU_B12_C2_START,        GG_ECU_B12_C2_L,         /* C2 B12 */
  (word *)GG_ECU_B13_C2_START,        GG_ECU_B13_C2_L,         /* C2 B13 */
  (word *)GG_ECU_B14_C2_START,        GG_ECU_B14_C2_L,         /* C2 B14 */
#endif

#ifdef LEC_TECENG
  GG_NUM_TECENG_CH_BUFF,
  
  (word *)GG_TEC_CH_B0_C2_START,         GG_TEC_CH_B0_C2_L,          /* C2 B4 */
  (word *)GG_TEC_CH_B1_C2_START,         GG_TEC_CH_B1_C2_L,          /* C2 B5 */
  (word *)GG_TEC_CH_B2_C2_START,         GG_TEC_CH_B2_C2_L,          /* C2 B6 */
  (word *)GG_TEC_CH_B3_C2_START,         GG_TEC_CH_B3_C2_L,          /* C2 B7 */
  (word *)GG_TEC_CH_B4_C2_START,         GG_TEC_CH_B4_C2_L,          /* C2 B8 */
  (word *)GG_TEC_CH_B5_C2_START,         GG_TEC_CH_B5_C2_L,
#endif

#ifdef GG_INCLUDE_AER  

  GG_NUM_AER_BUFF,                                             /* AER Buffers */
  0x0000,0x0000,                                                /* C2 B0 */
  0x0000,0x0000,                                                /* C2 B1 */
  0x0000,0x0000,                                                /* C2 B2 */
  0x0000,0x0000,                                                /* C2 B3 */
  0x0000,0x0000,                                                /* C2 B4 */
  0x0000,0x0000,                                                /* C2 B5 */
  0x0000,0x0000,                                                /* C2 B6 */
  0x0000,0x0000,                                                /* C2 B7 */
  0x0000,0x0000,                                                /* C2 B8 */
  0x0000,0x0000,                                                /* C2 B9 */


  GG_NUM_AGC_BUFF,                                             /* AGC Buffers */
  0x0000,0x0000,                                                /* C2 B0 */
#endif
  
  GG_NUM_PIU_BUFF,                                                   /* PIU Buffers */
#ifndef GG_PIU_C2_HEAP_ALLOC
  (word *)GG_PIU_B0_C2_START,         GG_PIU_B0_C2_L,          /* C2 B0 */
  (word *)GG_PIU_B1_C2_START,         GG_PIU_B1_C2_L,          /* C2 B1 */
  (word *)GG_PIU_B2_C2_START,         GG_PIU_B2_C2_L,          /* C2 B2 */
  (word *)GG_PIU_B3_C2_START,         GG_PIU_B3_C2_L,          /* C2 B3 */
#else
  0,0, 0,0, 0,0, 0,0, 
#endif

#ifdef GG_INCLUDE_TDU
  GG_NUM_TDU_BUFF,                                                   /* TDU Buffers */
  (word *)GG_TDU_B0_C2_START,         GG_TDU_B0_C2_L,          /* C2 B0 */
  (word *)GG_TDU_B1_C2_START,         GG_TDU_B1_C2_L,          /* C2 B1 */
  (word *)GG_TDU_B2_C2_START,         GG_TDU_B2_C2_L,          /* C2 B2 */
  (word *)GG_TDU_B3_C2_START,         GG_TDU_B3_C2_L,          /* C2 B3 */
  (word *)GG_TDU_B4_C2_START,         GG_TDU_B4_C2_L,          /* C2 B4 */
#endif

#ifdef GG_TDU_SAVEBUF_EXT
  GG_NUM_TDU_BUFF,                                                   /* TDU Buffers */
  (word *)GG_TDUFAX_B0_C2_START,         GG_TDUFAX_B0_C2_L,   /* C2 B0 */
  (word *)GG_TDUFAX_B1_C2_START,         GG_TDUFAX_B1_C2_L,   /* C2 B1 */
  (word *)GG_TDUFAX_B2_C2_START,         GG_TDUFAX_B2_C2_L,   /* C2 B2 */
  (word *)GG_TDUFAX_B3_C2_START,         GG_TDUFAX_B3_C2_L,   /* C2 B3 */
  (word *)GG_TDUFAX_B4_C2_START,         GG_TDUFAX_B4_C2_L,   /* C2 B4 */
#endif

#ifdef PLR_VOICE_OVERLAY
  GG_NUM_TDU_BUFF,                                                   /* TDU Buffers */
  (word *)GG_TDULITE_B0_C2_START,     GG_TDULITE_B0_C2_L,      /* C2 B0 */
  (word *)GG_TDULITE_B1_C2_START,     GG_TDULITE_B1_C2_L,      /* C2 B1 */
  (word *)GG_TDULITE_B2_C2_START,     GG_TDULITE_B2_C2_L,      /* C2 B2 */
  (word *)GG_TDULITE_B3_C2_START,     GG_TDULITE_B3_C2_L,      /* C2 B3 */
  (word *)GG_TDULITE_B4_C2_START,     GG_TDULITE_B4_C2_L,      /* C2 B4 */
#endif

#if defined(VOICE) || defined(VOICE_FAX)    
  GG_NUM_VPU_BUFF,                                                   /* VPU Buffers */
#ifndef GG_VPU_C2_HEAP_ALLOC
  (word *)GG_VPU_B0_C2_START,         GG_VPU_B0_C2_L,          /* C2 B0 */
  (word *)GG_VPU_B1_C2_START,         GG_VPU_B1_C2_L,          /* C2 B1 */
#else
  0,0, 0,0, 
#endif
#endif

#if defined(VOICE) || defined(VOICE_FAX)    
  GG_NUM_PVP_BUFF,                                                   /* PVP Buffers */
#ifndef GG_PVP_C2_HEAP_ALLOC
  (word *)GG_PVP_B0_C2_START,         GG_PVP_B0_C2_L,          /* C2 B0 */
  (word *)GG_PVP_B1_C2_START,         GG_PVP_B1_C2_L,          /* C2 B1 */
  (word *)GG_PVP_B2_C2_START,         GG_PVP_B2_C2_L,          /* C2 B2 */
  (word *)GG_PVP_B3_C2_START,         GG_PVP_B3_C2_L,          /* C2 B3 */
#else
  0,0, 0,0, 0,0, 0,0, 
#endif
#endif
  
#if defined(VOICE) || defined(VOICE_FAX)    
  GG_NUM_TGU_BUFF,                                             /* TGU Buffers */
#ifndef GG_TGU_C2_HEAP_ALLOC
  (word *)GG_TGU_B0_C2_START,         GG_TGU_B0_C2_L,          /* C2 B0 */
#else
  0,0, 
#endif
#endif
  
#if defined(VOICE) || defined(VOICE_FAX)    
  GG_NUM_CID_BUFF,                                                   /* CID Buffers */
#ifdef GG_INCLUDE_CID
  (word *)GG_CID_B0_C2_START,         GG_CID_B0_C2_L,          /* C2 B0 */
  (word *)GG_CID_B1_C2_START,         GG_CID_B1_C2_L,          /* C2 B1 */
  (word *)GG_CID_B2_C2_START,         GG_CID_B2_C2_L,          /* C2 B2 */
  (word *)GG_CID_B3_C2_START,         GG_CID_B3_C2_L,          /* C2 B3 */
#else
  0,0, 0,0, 0,0, 0,0, 
#endif
#endif

#ifdef GG_INCLUDE_RSU  
  GG_NUM_RSU_BUFF,                                             /* RSU Buffers */
  0x0000,0x0000,                                                /* C2 B0 */
  0x0000,0x0000,                                                /* C2 B1 */
  0x0000,0x0000,                                                /* C2 B2 */
#endif

#if (defined(GG_INCLUDE_AAL1) || defined(GG_INCLUDE_AAL2))  
  GG_NUM_ACU_BUFF,                                                   /* ACU Buffers */

  (word *)GG_ACU_B0_C2_START,         GG_ACU_B0_C2_L,          /* C2 B0 */
#endif



#ifdef GG_INCLUDE_RTP
  GG_NUM_RCU_BUFF,                                                   /* RCU Buffers */

  (word *)GG_RCU_B0_C2_START,         GG_RCU_B0_C2_L,          /* C2 B0 */
  (word *)GG_RCU_B1_C2_START,         GG_RCU_B1_C2_L,          /* C2 B1 */
  (word *)GG_RCU_B2_C2_START,         GG_RCU_B2_C2_L,          /* C2 B2 */
#endif

#if (defined(PLRRED) || defined(PLRFEC))
#ifdef PLR_VOICE_OVERLAY
#if (MAX_RED_LEVEL_TEXT > 0)
  GG_NUM_PLR_BUFF,                                                   /* PLR Buffers */
  (word *)GG_PLR_B0_C2_START,         GG_PLR_B0_C2_L,          /* C2 B0 */
  (word *)GG_PLR_B1_C2_START,         GG_PLR_B1_C2_L,          /* C2 B1 */
  (word *)GG_PLR_B2_C2_START,         GG_PLR_B2_C2_L,          /* C2 B2 */
#ifdef PLR_USE_GMP_SUPPLEMENT
  (word *)GG_PLR_B3_C2_START,         GG_PLR_B3_C2_L,          /* C2 B3 */
#endif
#endif
#if ((MAX_RED_LEVEL_VOICE > 0) || (MAX_FEC_LEVEL_2198 > 0))
  GG_NUM_PLR_BUFF,                                                   /* PLR Buffers */
  (word *)GG_PLRVBD_B0_C2_START,      GG_PLRVBD_B0_C2_L,       /* C2 B0 */
  (word *)GG_PLRVBD_B1_C2_START,      GG_PLRVBD_B1_C2_L,       /* C2 B1 */
  (word *)GG_PLRVBD_B2_C2_START,      GG_PLRVBD_B2_C2_L,       /* C2 B2 */
#ifdef PLR_USE_GMP_SUPPLEMENT
  (word *)GG_PLRVBD_B3_C2_START,      GG_PLRVBD_B3_C2_L,       /* C2 B3 */
#endif
#endif
#if ((MAX_RED_LEVEL_FAX > 0) && defined(GG_INCLUDE_FAX_RELAY))
  GG_NUM_PLR_BUFF,                                                   /* PLR Buffers */
  (word *)GG_PLRFAX_B0_C2_START,      GG_PLRFAX_B0_C2_L,       /* C2 B0 */
  (word *)GG_PLRFAX_B1_C2_START,      GG_PLRFAX_B1_C2_L,       /* C2 B1 */
  (word *)GG_PLRFAX_B2_C2_START,      GG_PLRFAX_B2_C2_L,       /* C2 B2 */
#ifdef PLR_USE_GMP_SUPPLEMENT
  (word *)GG_PLRFAX_B3_C2_START,      GG_PLRFAX_B3_C2_L,       /* C2 B3 */
#endif
#endif
#else /* OVERLAY - none */
  GG_NUM_PLR_BUFF,                                                   /* PLR Buffers */
  (word *)GG_PLR_B0_C2_START,         GG_PLR_B0_C2_L,          /* C2 B0 */
  (word *)GG_PLR_B1_C2_START,         GG_PLR_B1_C2_L,          /* C2 B1 */
  (word *)GG_PLR_B2_C2_START,         GG_PLR_B2_C2_L,          /* C2 B2 */
#ifdef PLR_USE_GMP_SUPPLEMENT
  (word *)GG_PLR_B3_C2_START,         GG_PLR_B3_C2_L,          /* C2 B3 */
#endif
#endif
#endif


#ifdef GG_INCLUDE_MSU
  GG_NUM_MSURTP_BUFF,                                                   /* MSU RTP Buffers */
#ifndef GG_MSU_RTP_C2_HEAP_ALLOC
  (word *)GG_MSU_RTP_B0_C2_START,     GG_MSU_RTP_B0_C2_L,    /* C2 B0 */
#else
  0,0,  
#endif

  GG_NUM_MSURTCP_BUFF,                                              /* MSU RTCP Buffers */
#ifndef GG_MSU_RTCP_C2_HEAP_ALLOC
  (word *)GG_MSU_RTCP_B0_C2_START,    GG_MSU_RTCP_B0_C2_L,   /* C2 B0 */
#else
  0,0,  
#endif
#endif

#ifdef GG_INCLUDE_NET_ENCAP

  GG_NUM_NEU_BUFF,                                                   /* NEU Buffers */
#ifndef GG_NEU_C2_HEAP_ALLOC
  (word *)GG_NEU_B0_C2_START,         GG_NEU_B0_C2_L,          /* C2 B0 */
  (word *)GG_NEU_B1_C2_START,         GG_NEU_B1_C2_L,          /* C2 B1 */
  (word *)GG_NEU_B2_C2_START,         GG_NEU_B2_C2_L,          /* C2 B2 */
  (word *)GG_NEU_B3_C2_START,         GG_NEU_B3_C2_L,          /* C2 B3 */
  (word *)GG_NEU_B4_C2_START,         GG_NEU_B4_C2_L,          /* C2 B4 */
#else
  0,0, 0,0, 0,0, 0,0, 0,0,
#endif
#endif
  
#ifdef GG_INCLUDE_ANNOUNCEMENTS
  GG_NUM_ANU_BUFF,                                             /* NEU Buffers */
#ifndef GG_ANU_C2_HEAP_ALLOC
  (word *)GG_ANU_B0_C2_START,         GG_ANU_B0_C2_L,          /* C2 B0 */
#else
  0,0,
#endif
#endif

#ifdef GG_INCLUDE_PRU
  GG_NUM_PRU_BUFF,                                             /* PRU Buffers */
#ifndef GG_PRU_C2_HEAP_ALLOC
  (word *)GG_PRU_B0_C2_START,         GG_PRU_B0_C2_L,  /* C2 B0 */
#else
  0,0,
#endif
#endif

#ifdef GG_INCLUDE_TTU
  GG_NUM_TTU_BUFF,                                                   /* TTU Buffers */
#ifndef GG_TTU_C2_HEAP_ALLOC
  (word *)GG_TTU_B0_C2_START,         GG_TTU_B0_C2_L,          /* C2 B0 */
#else
  0,0,
#endif
#endif


#ifdef GG_INCLUDE_FAX_RELAY
  
#if defined(FAX) || defined(VOICE_FAX)    
  GG_NUM_FM_BUFF,                                             /* DPU Buffers */
#ifndef GG_FM_C2_HEAP_ALLOC
  (word *)GG_FM_B0_C2_START,          GG_FM_B0_C2_L,           /* C2 B0 */
  (word *)GG_FM_B1_C2_START,          GG_FM_B1_C2_L,           /* C2 B1 */
  (word *)GG_FM_B2_C2_START,          GG_FM_B2_C2_L,           /* C2 B2 */
  (word *)GG_FM_B3_C2_START,          GG_FM_B3_C2_L,           /* C2 B3 */
  (word *)GG_FM_B4_C2_START,          GG_FM_B4_C2_L,           /* C2 B4 */
  (word *)GG_FM_B5_C2_START,          GG_FM_B5_C2_L,           /* C2 B5 */
  (word *)GG_FM_B6_C2_START,          GG_FM_B6_C2_L,           /* C2 B6 */
  (word *)GG_FM_B7_C2_START,          GG_FM_B7_C2_L,           /* C2 B7 */
  (word *)GG_FM_B8_C2_START,          GG_FM_B8_C2_L,           /* C2 B8 */
  (word *)GG_FM_B9_C2_START,          GG_FM_B9_C2_L,           /* C2 B9 */
  (word *)GG_FM_B10_C2_START,         GG_FM_B10_C2_L,          /* C2 B10 */
  (word *)GG_FM_B11_C2_START,         GG_FM_B11_C2_L,          /* C2 B11 */
  (word *)GG_FM_B12_C2_START,         GG_FM_B12_C2_L,          /* C2 B12 */
  (word *)GG_FM_B13_C2_START,         GG_FM_B13_C2_L,          /* C2 B13 */
  (word *)GG_FM_B14_C2_START,         GG_FM_B14_C2_L,          /* C2 B14 */
  (word *)GG_FM_B15_C2_START,         GG_FM_B15_C2_L,          /* C2 B15 */
  (word *)GG_FM_B16_C2_START,         GG_FM_B16_C2_L,          /* C2 B16 */
  (word *)GG_FM_B17_C2_START,         GG_FM_B17_C2_L,          /* C2 B17 */
  (word *)GG_FM_B18_C2_START,         GG_FM_B18_C2_L,          /* C2 B18 */
  (word *)GG_FM_B19_C2_START,         GG_FM_B19_C2_L,          /* C2 B19 */
  (word *)GG_FM_B20_C2_START,         GG_FM_B20_C2_L,          /* C2 B20 */
#else
  0,0, 0,0, 0,0, 0,0, 0,0, 0,0, 0,0, 0,0, 0,0, 0,0,  
  0,0, 0,0, 0,0, 0,0, 0,0, 0,0, 0,0, 0,0, 0,0, 0,0, 0,0, 
#endif
#endif
  
#if defined(FAX) || defined(VOICE_FAX)    
  GG_NUM_FIU_BUFF,                                             /* FIU Buffers */
#ifndef GG_FIU_C2_HEAP_ALLOC
  (word *)GG_FIU_B0_C2_START,         GG_FIU_B0_C2_L,          /* C2 B0 */
  (word *)GG_FIU_B1_C2_START,         GG_FIU_B1_C2_L,          /* C2 B1 */
  (word *)GG_FIU_B2_C2_START,         GG_FIU_B2_C2_L,          /* C2 B2 */
  (word *)GG_FIU_B3_C2_START,         GG_FIU_B3_C2_L,          /* C2 B3 */
  (word *)GG_FIU_B4_C2_START,         GG_FIU_B4_C2_L,          /* C2 B3 */
#else
  0,0, 0,0, 0,0, 0,0,0,0, 
#endif
#endif

#endif /* GG_INCLUDE_FAX_RELAY */


#ifdef GG_INCLUDE_MODEM_RELAY  
  GG_NUM_MRU_BUFF,                                             /* MRU Buffers */
  0x0000,0x0000,                                                /* C2 B0 */
  0x0000,0x0000,                                                /* C2 B1 */
  0x0000,0x0000,                                                /* C2 B2 */
  0x0000,0x0000,                                                /* C2 B3 */
  0x0000,0x0000,                                                /* C2 B4 */
  0x0000,0x0000,                                                /* C2 B5 */
#endif

#ifdef GG_INCLUDE_MDMCP
  GG_NUM_MDMCP_BUFF,                                               /* MDMCP Buffers */
  0,0, 
  0,0, 
#endif

#if defined(GG_INCLUDE_DATA_MODEM) || defined(GG_INCLUDE_LINK_LAYER_MODEM_RELAY)
  GG_NUM_DMP_BUFF,                                                   /* DMP Buffers */
  0,0, 
  0,0, 
  0,0, 
  0,0, 
  0,0, 
  0,0, 
#endif

#if (defined (GG_INCLUDE_CLEAR_DATA) || defined (GG_INCLUDE_FAX_MODEM) || defined (GG_INCLUDE_DATA_MODEM) || defined (AUDIO))
  GG_NUM_MPP_BUFF,                                                   /* MPP Buffers */
#ifndef GG_MPP_C2_HEAP_ALLOC
  (word *)GG_MPP_B0_C2_START,        GG_MPP_B0_C2_L,         /* C2 B0 */
  (word *)GG_MPP_B1_C2_START,        GG_MPP_B1_C2_L,         /* C2 B1 */
  (word *)GG_MPP_B2_C2_START,        GG_MPP_B2_C2_L,         /* C2 B2 */
#else
  0,0, 
  0,0, 
  0,0,  
#endif

#endif

#ifdef GG_INCLUDE_BERT
  GG_NUM_BERT_BUFF,                                                 /* BERT Buffers */
  0,0, 
#endif

#ifdef NX64 
  GG_NUM_NXU_BUFF,                                                    /* NXU Buffers */
#ifndef GG_NXU_C2_HEAP_ALLOC
  (word *)GG_NXU_B0_C2_START,        GG_NXU_B0_C2_L,         /* C2 B0 */
  (word *)GG_NXU_B1_C2_START,        GG_NXU_B1_C2_L,         /* C2 B1 */
#else
  0,0,0,0, 
#endif
#endif

#ifdef EQI 
  GG_NUM_EQI_BUFF,                                                    /* EQI Buffers */
#ifndef GG_EQI_C2_HEAP_ALLOC
  (word *)GG_EQI_B0_C2_START,        GG_EQI_B0_C2_L,         /* C2 B0 */
#else
  0,0, 
#endif
#endif

#ifdef GG_INCLUDE_VQM
  GG_NUM_VQM_BUFF,
  0,0, 
#endif

#ifdef GG_INCLUDE_LINK_LAYER_MODEM_RELAY
  GG_NUM_LLMRU_BUFF,                                               /* LLMRU Buffers */
  0,0, 
  0,0, 
  0,0, 
  0,0, 
  0,0, 
  0,0, 
  0,0, 
  0,0, 
  0,0, 
  0,0, 
  0,0, 
  0,0, 
  0,0, 
  0,0, 
  0,0, 
  0,0, 
  0,0, 
  0,0, 
  0,0,

  GG_NUM_SPRTP_BUFF,                                               /* SPRTP Buffers */
  0,0, 
  0,0, 
#endif

#if defined(VOICE) || defined(VOICE_FAX)    
  GG_NUM_TX_NMU_BUFF,
#ifdef G711A2
  (word *)GG_TX_NMU_B0_C2_START,     GG_TX_NMU_B0_C2_L,      /* C2 B0 */
  (word *)GG_TX_NMU_B1_C2_START,     GG_TX_NMU_B1_C2_L,      /* C2 B1 */
  (word *)GG_TX_NMU_B2_C2_START,     GG_TX_NMU_B2_C2_L,      /* C2 B2 */    
#else
  (word *)GG_TX_NMU_B0_C2_START,     GG_TX_NMU_B0_C2_L,      /* C2 B0 */
#endif
#endif


#if defined(VOICE) || defined(VOICE_FAX)    
  GG_NUM_RX_NMU_BUFF,
#ifdef G711A2
  (word *)GG_RX_NMU_B0_C2_START,     GG_RX_NMU_B0_C2_L,      /* C2 B0 */
  (word *)GG_RX_NMU_B1_C2_START,     GG_RX_NMU_B1_C2_L,      /* C2 B1 */
  (word *)GG_RX_NMU_B2_C2_START,     GG_RX_NMU_B2_C2_L,      /* C2 B2 */    
#else
  (word *)GG_RX_NMU_B0_C2_START,     GG_RX_NMU_B0_C2_L,      /* C2 B0 */
#endif
#endif


#if defined(VOICE) || defined(VOICE_FAX)    
 GG_NUM_PLC_BUFF,
#ifdef G711A1
  (word *)GG_PLC_B0_C2_START,        GG_PLC_B0_C2_L,      /* C2 B0 */
  (word *)GG_PLC_B1_C2_START,        GG_PLC_B1_C2_L,      /* C2 B1 */
  (word *)GG_PLC_B2_C2_START,        GG_PLC_B2_C2_L,      /* C2 B2 */
  (word *)GG_PLC_B3_C2_START,        GG_PLC_B3_C2_L,      /* C2 B3 */
  (word *)GG_PLC_B4_C2_START,        GG_PLC_B4_C2_L,      /* C2 B4 */
#else
  (word *)GG_PLC_B0_C2_START,        GG_PLC_B0_C2_L,      /* C2 B0 */
#endif
#endif


#ifdef GG_MULTSAMPVC
  GG_NUM_MULTSAMPVC_BUFF,
  0,0,
  0,0,
  0,0, 
  0,0, 
  0,0,
#endif

#ifdef VEU
  GG_NUM_VEU_BUFF,
#ifndef GG_VEU_C2_HEAP_ALLOC
  (word *)GG_VEU_B0_C2_START,         GG_VEU_B0_L,          /* C2 B0 */  
#else
  0,0,
#endif
#endif

#ifdef AUDIO
  GG_NUM_ADU_BUFF,                                                   /* PIU Buffers */
#ifndef GG_ADU_C2_HEAP_ALLOC
  (word *)GG_ADU_B0_C2_START,         GG_ADU_B0_C2_L,          /* C2 B0 */
  (word *)GG_ADU_B1_C2_START,         GG_ADU_B1_C2_L,          /* C2 B1 */
  (word *)GG_ADU_B2_C2_START,         GG_ADU_B2_C2_L,          /* C2 B2 */
  (word *)GG_ADU_B3_C2_START,         GG_ADU_B3_C2_L,          /* C2 B3 */
  (word *)GG_ADU_B4_C2_START,         GG_ADU_B4_C2_L,          /* C2 B4 */
  (word *)GG_ADU_B5_C2_START,         GG_ADU_B5_C2_L,          /* C2 B5 */
  (word *)GG_ADU_B6_C2_START,         GG_ADU_B6_C2_L,          /* C2 B6 */
  (word *)GG_ADU_B7_C2_START,         GG_ADU_B7_C2_L,          /* C2 B7 */
#else
  0,0, 0,0, 0,0, 0,0, 0,0, 0,0, 0,0, 0,0,
#endif
#endif

#ifdef NX64 
  GG_NUM_NPIU_BUFF,                                                  /* NPIU Buffers */
#ifndef GG_NPIU_C2_HEAP_ALLOC
  (word *)GG_NPIU_B0_C2_START,        GG_NPIU_B0_C2_L,       /* C2 B0 */
  (word *)GG_NPIU_B1_C2_START,        GG_NPIU_B1_C2_L,       /* C2 B1 */
  (word *)GG_NPIU_B2_C2_START,        GG_NPIU_B2_C2_L,       /* C2 B2 */
#else
  0,0,0,0,0,0, 
#endif
#endif

#ifdef HDVIDEO
  GG_NUM_VTK_BUFF,                                                  /* VTK Buffers */
#ifndef GG_VTK_C2_HEAP_ALLOC
  (word *)GG_VTK_B0_C2_START,        GG_VTK_B0_C2_L,        /* C2 B0 */
#else
  0,0,
#endif

  GG_NUM_ATK_BUFF,                                                  /* ATK Buffers */
#ifndef GG_ATK_C2_HEAP_ALLOC
  (word *)GG_ATK_B0_C2_START,        GG_ATK_B0_C2_L,        /* C2 B0 */
  (word *)GG_ATK_B1_C2_START,        GG_ATK_B1_C2_L,        /* C2 B1 */
#else
  0,0,0,0,
#endif


  GG_NUM_TSU_BUFF,                                                  /* TSU Buffers */
#ifndef GG_TSU_C2_HEAP_ALLOC
  (word *)GG_TSU_B0_C2_START,        GG_TSU_B0_C2_L,        /* C2 B0 */
  (word *)GG_TSU_B1_C2_START,        GG_TSU_B1_C2_L,        /* C2 B1 */
#else
  0,0,0,0,
#endif

/*=======================================================================*/
/* Video Build: customEco buffers here                                   */
/*=======================================================================*/
  GG_NUM_CUSTOM_ECO_BUFF,                                           /* CUSTOM_ECO Buffers */
#ifndef GG_CUSTOM_ECO_C2_HEAP_ALLOC
  (word *)GG_CUSTOM_ECO_B0_C2_START,        GG_CUSTOM_ECO_B0_C2_L,  /* C2 B0 */
#else
  0,0,
#endif
/*=======================================================================*/
/* Video Build: customEco buffers, unitl here                            */
/*=======================================================================*/

  GG_NUM_OVLY_BUFF,                                           /* OVLY Buffers */
#ifndef GG_OVLY_C2_HEAP_ALLOC
  (word *)GG_OVLY_B0_C2_START,        GG_OVLY_B0_C2_L,  /* C2 B0 */
#else
  0,0,
#endif

  GG_NUM_MMCU_BUFF,                                           /* MMCU Buffers */
#ifndef GG_MMCU_C2_HEAP_ALLOC
  (word *)GG_MMCU_B0_C2_START,        GG_MMCU_B0_C2_L,  /* C2 B0 */
  (word *)GG_MMCU_B1_C2_START,        GG_MMCU_B1_C2_L,  /* C2 B1 */  
#else
  0,0,0,0,
#endif
#endif

#if defined(HDCT) || defined(HDVIDEO) 
  GG_NUM_VPPU_BUFF,                                                  /* VPPU Buffers */
#ifndef GG_VPPU_C2_HEAP_ALLOC
  (word *)GG_VPPU_B0_C2_START,        GG_VPPU_B0_C2_L,       /* C2 B0 */
  (word *)GG_VPPU_B1_C2_START,        GG_VPPU_B1_C2_L,       /* C2 B1 */
  (word *)GG_VPPU_B2_C2_START,        GG_VPPU_B2_C2_L,       /* C2 B2 */
#else
  0,0,0,0,0,0,
#endif
  GG_NUM_TFTP_BUFF,                                           /* TFTP Buffers */
#ifndef GG_TFTP_C2_HEAP_ALLOC
  (word *)GG_TFTP_B0_C2_START,        GG_TFTP_B0_C2_L,  /* C2 B0 */
#else
  0,0,
#endif
#endif

  /* End expansion $ch = 2 */
 
};

/* nothing past this point */
