/****************************************************************************
 * FILE PURPOSE: Storage of internal memory buffers
 ****************************************************************************
 * FILE NAME:  ggmemdef.bec
 *
 * DESCRIPTION: This file is used to create sections in the linker file
 *              for simulating memory map defined in ggmemmap.beh
 *
 * TABS: NONE
 *
 * (C) Copyright 2003, Texas Instruments Incorporated.
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/

#include "ggswcfg.h"
#include "gghwcfg.h"
#include "ggmemmap.h"
#include "ggmbuf.h"
#include "ggcfg.h"
#include "mgdefs.h"  /* defines dprword */
#include "vctypes.h"
#include "diagapp.h"

/****************************************************************************
 * Define memory buffer section names
 ***************************************************************************/
#pragma DATA_SECTION(gg_scratch, ".gg_scratch")
  char gg_scratch[GG_COMMON_SCRATCH_USED];

#pragma DATA_SECTION(gg_halheap, ".gg_halheap")
  char gg_halheap[GG_HAL_HEAP_END - GG_HAL_HEAP_START];

#pragma DATA_SECTION(gg_ndu_msg_fifos, ".gg_ndu_msg_fifos")
  char gg_ndu_msg_fifos[GG_GMNDU_MSG_FIFOS_USED];

#pragma DATA_SECTION(gg_neu_scratch, ".gg_neu_scratch");
  char gg_neu_scratch[GG_NEU_SCRATCH_USED];

#pragma DATA_SECTION(gg_gmndu_neu, ".gg_gmndu_neu");
  char gg_gmndu_neu[GG_GMNDU_NEU_USED];

/* Expanding $ch = 1 */
#pragma DATA_SECTION(gg_ch1_buf, ".gg_ch1")
  char gg_ch1_buf[GG_CH1_USED];
/* End expansion $ch = 1 */
/* Expanding $ch = 2 */
#pragma DATA_SECTION(gg_ch2_buf, ".gg_ch2")
  char gg_ch2_buf[GG_CH2_USED];
/* End expansion $ch = 2 */


#pragma DATA_SECTION(gg_gmp0, ".gg_gmp0")
  char gg_gmp0[GG_DATA_GMP0_END - GG_DATA_GMP0_START];

#pragma DATA_SECTION(gg_tdm_dma_rx, ".gg_tdm_dma_rx")
char gg_tdm_dma_rx[GG_BSP_ALLOCATED_SIZE];

#pragma DATA_SECTION(gg_tdm_dma_tx, ".gg_tdm_dma_tx")
char gg_tdm_dma_tx[GG_BSP_ALLOCATED_SIZE];

#pragma DATA_SECTION(diagAppMem, ".diagApp")
diagApp_t diagAppMem;

#define GG_NULL_POOL_BUILD0 {                    \
    /* Range starting address */                 \
    (word *)0,                                   \
    /* Range length */                           \
    (word *)0,                                   \
    /* Chunk Size */                             \
    (tulong)0                                    \
}

#define GG_NULL_SCRATCH_BUILD0 {                 \
    /* Range starting address */                 \
    (word *)0,                                   \
    /* Range length */                           \
    (word *)0                                    \
}

/* Build definitions */
vigdkMemoryContext_t gg_supported_builds[] =
{
   /* QCIF/CIF Build */
   {
     GG_NULL_POOL_BUILD0,
     GG_NULL_POOL_BUILD0,
     GG_NULL_POOL_BUILD0,
     GG_NULL_POOL_BUILD0,
     GG_NULL_POOL_BUILD0,
     GG_NULL_POOL_BUILD0,
     GG_NULL_POOL_BUILD0,
     GG_NULL_POOL_BUILD0,
     GG_NULL_POOL_BUILD0,
     GG_NULL_POOL_BUILD0,
     GG_NULL_POOL_BUILD0,
     GG_NULL_POOL_BUILD0,
     GG_NULL_SCRATCH_BUILD0,
     GG_NULL_SCRATCH_BUILD0,
     GG_NULL_SCRATCH_BUILD0,
     GG_NULL_SCRATCH_BUILD0,
     GG_NULL_SCRATCH_BUILD0,
     { 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 143,
	   144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, -1 },
     { 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
	   0x4, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0}
   }
};

/* nothing past this point */
