/****************************************************************************
 * FILE PURPOSE: Allocation tables with addresses for memory buffers and heap
 ****************************************************************************
 * FILE NAME:  ggmheap.bec
 *
 * DESCRIPTION:  This file contains the allocation table for all ECO memory
 *               heaps and voice/fax heap for each channel.
 *
 * TABS: NONE
 *
 * (C) Copyright 2003, Texas Instruments Incorporated.
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/

#include "ggmbuf.h"
#include "ggmemmap.h"
#include "ggcfg.h"
#include "ggswcfg.h"
#include "ggchBufDesc.h"
#include "vctypes.h"
#include "ggCodecSwap.h"
#include "rttrace.h"

#ifdef GG_MEM_BUF_RELOC
static inline ggRelocAddr(word *base, word **addr)
{
   *addr = base + (tulong) *addr;
} 
void ggchRelocAllChAddr(word *base, word *chAddr[])
{
  int i;
  for(i = 0; i < (GG_MAX_NUM_CHANNELS+GG_MAX_PKT2PKT_CHANNELS); i++) {
    ggRelocAddr(base, &chAddr[i]);  
  }
}
#endif

#if ( defined(VOICE) || defined(VOICE_FAX) || defined(HDMOVE) || defined(HDSKEL) || defined(HDVIDEO) || defined(HDCT))
 word * relocQualifier ggchVoiceHeapStartAddr[GG_MAX_NUM_SLOTS+GG_MAX_AUX_PCM_CHANNELS] =
 {                      
   /* Expanding $ch = 1 */
   (word *)GG_VOICE_HEAP_C1_START,      /* Channel 1 Voice memory heap */
   /* End expansion $ch = 1 */
/* Expanding $ch = 2 */
   (word *)GG_VOICE_HEAP_C2_START,      /* Channel 2 Voice memory heap */
   /* End expansion $ch = 2 */
 

 };
 relocQualifier tuint ggchVoiceHeapSize = GG_VOICE_HEAP_L;
#endif
   relocQualifier tuint ggchVoiceAuxHeapSize =  GG_VOICE_AUX_HEAP_L;
#if ( defined(GG_INCLUDE_FAX_RELAY) || defined(GG_INCLUDE_FAX_MODEM) )
 word * relocQualifier ggchFaxHeapStartAddr[GG_MAX_NUM_SLOTS] =
 {                    
   /* Expanding $ch = 1 */
   (word *)GG_FAX_HEAP_C1_START,        /* Channel 1 FAX memory heap   */
   /* End expansion $ch = 1 */
/* Expanding $ch = 2 */
   (word *)GG_FAX_HEAP_C2_START,        /* Channel 2 FAX memory heap   */
   /* End expansion $ch = 2 */
 
 };
 relocQualifier tuint ggchFaxHeapSize = GG_FAX_HEAP_L;
#endif

#ifdef GG_INCLUDE_CLEAR_DATA
 word * relocQualifier ggchClearDataHeapStartAddr[GG_MAX_NUM_SLOTS] =
 {                   
   /* Expanding $ch = 1 */
   (word *)GG_HDCM_HEAP_C1_START, /* Channel 1 Clear Data memory heap   */
   /* End expansion $ch = 1 */
/* Expanding $ch = 2 */
   (word *)GG_HDCM_HEAP_C2_START, /* Channel 2 Clear Data memory heap   */
   /* End expansion $ch = 2 */
 
 };
 relocQualifier tuint ggchClearDataHeapSize = GG_HDCM_HEAP_L;
#endif

#ifdef GG_INCLUDE_LINK_LAYER_MODEM_RELAY
 word * relocQualifier ggchLLMRheapStartAddr[GG_MAX_NUM_SLOTS] =
 {                    
   /* Expanding $ch = 1 */
   (word *)GG_LLMR_HEAP_C1_START /* Channel 1 Link Layer Modem Relay memory heap   */
   /* End expansion $ch = 1 */
/* Expanding $ch = 2 */
   (word *)GG_LLMR_HEAP_C2_START /* Channel 2 Link Layer Modem Relay memory heap   */
   /* End expansion $ch = 2 */
 
 };
 relocQualifier tuint ggchLLMRheapSize = GG_LLMR_HEAP_L;
#endif

#ifdef GG_INCLUDE_DATA_MODEM
 word * relocQualifier ggchModemHeapStartAddr[GG_MAX_NUM_SLOTS] =
 {                    
   /* Expanding $ch = 1 */
   (word *)GG_MODEM_HEAP_C1_START /* Channel 1 Link Layer Modem Relay memory heap   */
   /* End expansion $ch = 1 */
/* Expanding $ch = 2 */
   (word *)GG_MODEM_HEAP_C2_START /* Channel 2 Link Layer Modem Relay memory heap   */
   /* End expansion $ch = 2 */
 
 };
 relocQualifier tuint ggchModemHeapSize = GG_MODEM_HEAP_L;
#endif

#ifdef AUDIO
 word * relocQualifier ggchAudioHeapStartAddr[GG_MAX_NUM_SLOTS] =
 {                   
   /* Expanding $ch = 1 */
   (word *)GG_AUDIO_HEAP_C1_START /* Channel 1 Link Layer Modem Relay memory heap   */
   /* End expansion $ch = 1 */
/* Expanding $ch = 2 */
   (word *)GG_AUDIO_HEAP_C2_START /* Channel 2 Link Layer Modem Relay memory heap   */
   /* End expansion $ch = 2 */
 
 };
 relocQualifier tuint ggchAudioHeapSize = GG_AUDIO_HEAP_L;
#endif

#ifdef NX64
 word * relocQualifier ggchnx64HeapStartAddr[GG_MAX_NUM_SLOTS] =
 {                    
   /* Expanding $ch = 1 */
   (word *)GG_NX64_HEAP_C1_START, /* Channel 1 Clear Data memory heap   */
   /* End expansion $ch = 1 */
/* Expanding $ch = 2 */
   (word *)GG_NX64_HEAP_C2_START, /* Channel 2 Clear Data memory heap   */
   /* End expansion $ch = 2 */
 
 };
 relocQualifier tuint ggchnx64HeapSize = GG_NX64_HEAP_L;
#endif

/* Conferencing Heap Buffer */
#ifdef GG_INCLUDE_CONFERENCING
#if (!defined(HDVIDEO) && !defined(HDCT))
 relocQualifier ggconfHeapDesc_t confHeapDesc = 
 {
   (word *)GG_CONF_HEAP_START, GG_CONF_HEAP_L
 };
 #endif
#endif

#ifdef GG_CBU_MAX_NUM_PARTICIPANT 
/* Conferencing Heap Buffer */
const ggconfHeapDesc_t cbuHeapDesc = 
{
  (word *)GG_CONF_HEAP_START, GG_CONF_HEAP_L                 
};
#endif

#ifdef LEC_TECENG 
/* TEC Engine Heap Buffer */
relocQualifier ggtecEngHeapDesc_t tecEngHeapDesc = 
{
  (word *)GG_TEC_ENG_HEAP_START, (GG_TEC_ENG_HEAP_END - GG_TEC_ENG_HEAP_START),
  (word *)GG_TEC_ENG_SCRATCH_START, GG_TEC_ENG_SCRATCH_L                   
};
#endif

#ifdef GG_INCLUDE_DSIGT
 relocQualifier ggdsigtHeapDesc_t dsigtHeapDesc =
 {
   (word *)GG_DSIGT_HEAP_START, GG_DSIGT_HEAP_L
 };
#endif

#if (defined(GG_INCLUDE_DSIGR_AAL2) || defined(GG_INCLUDE_DSIGR_RTP))
 relocQualifier ggdsigrHeapDesc_t dsigrHeapDesc =
 {
   (word *)GG_DSIGR_HEAP_START, GG_DSIGR_HEAP_L
 };
#endif

relocQualifier gghalHeapDesc_t halHeapDesc =
{
  (word *)GG_HAL_HEAP_START,(word *)GG_HAL_HEAP_END, GG_HAL_HEAP_L
};

#ifdef GG_MEM_BUF_RELOC 
 relocQualifier tulong ggmbufStartAddrInPRAM = (tulong)ggchBuffDesc;
#else
 extern word ggvmmbuf[];
 relocQualifier tulong ggmbufStartAddrInPRAM = (tulong)ggvmmbuf;
#endif
relocQualifier tint   PrGGMBufScratchSize   = PRGGMBUF_SCRATCH_L;

const tuint  gg_sslot_mid[]        = {
/* Put other module IDs here if they should allocate from second pcm channel */

#ifdef GG_SSLOT_FAX_FM
  SIU_MID_FM,
#endif

#ifdef GG_SSLOT_FAX_FIU
  SIU_MID_FIU,
#endif

#ifdef GG_SSLOT_NX64
  SIU_MID_NPIU,
  SIU_MID_NXU,
#endif

  0
};

#ifdef GG_DYNSUBSLOT
const tuint  gg_codec_2ndsslot[] = {
/* Put other coding types here if they should allocate encoder and decoder
 * buffers on different sub slot */
#ifdef GG_INCLUDE_GSMAMR
  #ifndef GG_GSMAMR_DEC_BUFS_EXT  
    EVCT_GSMAMR,
  #endif 
#endif
#ifdef GG_INCLUDE_EVRC
  EVCT_EVRCFULL,
#endif

#ifdef GG_INCLUDE_ILBC
  EVCT_ILBC_RATE_20MS,
  EVCT_ILBC_RATE_30MS,
#endif

  0
};
#endif


/****************************************************************************
 * MIPS Agent buffer allocation 
 ***************************************************************************/
#ifdef GG_INCLUDE_ECUMA
#ifdef GG_SHARED_MEM_DATA_ALLOCATION 
#pragma DATA_SECTION (gg_ecuma_queue1, ".ecuma_bufs");
#pragma DATA_SECTION (gg_ecuma_queue2, ".ecuma_bufs");
#pragma DATA_SECTION (gg_ecuma_priority, ".ecuma_bufs");
#pragma DATA_SECTION (gg_ecuma_buf1, ".ecuma_bufs");
#endif
/* Search and BG LMS update channel queue */
tint gg_ecuma_queue1[GG_MAX_NUM_SLOTS];
tint gg_ecuma_queue2[GG_MAX_NUM_SLOTS];
/* Fuzzy priority buffer */
UFract gg_ecuma_priority[GG_MAX_NUM_SLOTS];
/* Channel context buffer */
ecumaChannel_t gg_ecuma_buf1[GG_MAX_NUM_SLOTS] =
{                     
  /* Expanding $ch = 1 */
  #if 1
  {0, 0, 0, {0, 0, 0}, {0, 0}, {0, 0}}, /* Channel 1 context */     
  #else /* Temporary ECUMA change to save 6 MIPS, pending for clean implementation */
  {0, 0, 0, 0, {0, 0, 0}, {0, 0}, {0, 0}}, /* Channel 1 context */     
  #endif
  /* End expansion $ch = 1 */
/* Expanding $ch = 2 */
  #if 1
  {0, 0, 0, {0, 0, 0}, {0, 0}, {0, 0}}, /* Channel 2 context */     
  #else /* Temporary ECUMA change to save 6 MIPS, pending for clean implementation */
  {0, 0, 0, 0, {0, 0, 0}, {0, 0}, {0, 0}}, /* Channel 2 context */     
  #endif
  /* End expansion $ch = 2 */
 
};
#endif  /* GG_INCLUDE_ECUMA */

word * relocQualifier ggTxNetwork_data[GG_MAX_NUM_SLOTS] =
{                    
  /* Expanding $ch = 1 */
   (word *)GG_TX_NETWORK_C1_START,
  /* End expansion $ch = 1 */
/* Expanding $ch = 2 */
   (word *)GG_TX_NETWORK_C2_START,
  /* End expansion $ch = 2 */
 
};

/****************************************************************************
 * SIU non-bss instance buffers on channel space
 ***************************************************************************/
#ifndef SIU_MULTICORE_SHARED_DATA
relocQualifier 
#endif

#pragma DATA_SECTION (gg_siuheap_inst, ".gg_siuheap_inst")
word *gg_siuheap_inst[GG_MAX_NUM_SLOTS] = {
                     
  /* Expanding $ch = 1 */
  (void *)GG_SIUHEAP_INST_C1_START,
  /* End expansion $ch = 1 */
/* Expanding $ch = 2 */
  (void *)GG_SIUHEAP_INST_C2_START,
  /* End expansion $ch = 2 */
 
};
/* Length of each SIU non-bss STATS buffer. Same accross all channels */
const tuint gg_siuheap_inst_len = GG_SIUHEAP_INST_L;

#ifdef GG_DYNSUBSLOT
relocQualifier word *gg_siu_inst[GG_MAX_NUM_SLOTS] = {
  /* Expanding $ch = 1 */
  (void *)GG_SIU_INST_C1_START,
  /* End expansion $ch = 1 */
/* Expanding $ch = 2 */
  (void *)GG_SIU_INST_C2_START,
  /* End expansion $ch = 2 */
 
};
/* Length of each SIU non-bss SIU instance. Same accross all channels */
const tuint gg_siu_inst_len = GG_SIU_INST_L;
#endif

#pragma DATA_SECTION (gg_siuheap_inst_ext, ".gg_siuheap_inst_ext")
word *gg_siuheap_inst_ext[GG_MAX_NUM_SLOTS] = {
                     
  /* Expanding $ch = 1 */
  (void *)GG_SIUHEAP_INST_EXT_C1_START,
  /* End expansion $ch = 1 */
/* Expanding $ch = 2 */
  (void *)GG_SIUHEAP_INST_EXT_C2_START,
  /* End expansion $ch = 2 */
 
};
/* Length of each SIU non-bss STATS buffer. Same accross all channels */
const tuint gg_siuheap_inst_ext_len = {
  GG_SIUHEAP_INST_EXT_L
};

/* Array for data page info for each channel. Each entry shows what extended
 * data page a corresponding channel expects before execution. */
const tuint gg_channelDataPageInfo[GG_MAX_NUM_CHANNELS] = {
#ifdef GG_MEM_BUF_RELOC /* there is no meaning of data page for relocatable code unless
                           we also provide page info during relocation */
                     
  /* Expanding $ch = 1 */
  0,
  /* End expansion $ch = 1 */
/* Expanding $ch = 2 */
  0,
  /* End expansion $ch = 2 */

#else 
  /* Expanding $ch = 1 */
  GG_CHAN_DATA_PAGE_C1,
  /* End expansion $ch = 1 */
/* Expanding $ch = 2 */
  GG_CHAN_DATA_PAGE_C2,
  /* End expansion $ch = 2 */
 
#endif  
};

#ifdef GG_INCLUDE_COMPOUND_MSG
/* Base address of compound scratch buffer for DSP->Micro used for compound message creation */
relocQualifier word *gg_compound_scratch = (word *)GG_COMPOUND_MSG_SCRATCH_START;
#endif

#if defined (HDVIDEO)
/* Base address of scratch buffer to feed the decoder */
relocQualifier word *gg_siu_rx_video_frame_scratch = (word *)GG_SIU_RX_VIDEO_FRAME_SCRATCH_START;
tulong gg_siu_rx_video_frame_scratch_size          = GG_SIU_RX_VIDEO_FRAME_SCRATCH_L;    

/* Base address of scratch buffer to hold the encoder output */
relocQualifier word *gg_siu_tx_video_frame_scratch = (word *)GG_SIU_TX_VIDEO_FRAME_SCRATCH_START;
tulong gg_siu_tx_video_frame_scratch_size          = GG_SIU_TX_VIDEO_FRAME_SCRATCH_L;

#endif

#ifdef SIUTBLPRG
const word *gg_msg_call_table_scratch = (word *)GG_MSG_CALL_TABLE_SCRATCH_START;
#endif

/* Number of GMP dedicated memory segments/areass: */
const tuint gg_gmp_no_segments = GG_GMP_AREAS;

/* TTU SCRATCH AREA */
#ifdef TTU
const word *gg_ttu_scratch = (word *)GG_TTU_SCRATCH_START;
#endif
  
/****************************************************************************
 * AER buffer allocation 
 ***************************************************************************/
#ifdef GG_INCLUDE_AER
 const ggaerHeapDesc_t aerHeapDesc[GG_NUM_AER_PORTS] =
 {
   /* Expanding $pr = 1 */
   (word *)GG_AER_HEAP_P1_START, GG_AER_HEAP_L,
   /* End expansion $pr = 1 */
/* Expanding $pr = 2 */
   (word *)GG_AER_HEAP_P2_START, GG_AER_HEAP_L,
   /* End expansion $pr = 2 */

 };
#endif /* GG_INCLUDE_AER */

#ifdef GG_MEM_BUF_RELOC
extern void ggchRelocEcoBufs(word *base);

/* main function which call all the above ggReloc functions */
void ggRelocDSPMem(word *base)
{
#if ( defined(VOICE) || defined(VOICE_FAX) )
  ggchRelocAllChAddr(base, ggchVoiceHeapStartAddr);
#endif

#if ( defined(GG_INCLUDE_FAX_RELAY) || defined(GG_INCLUDE_FAX_MODEM) )
  ggchRelocAllChAddr(base, ggchFaxHeapStartAddr);
#endif

#ifdef GG_INCLUDE_CLEAR_DATA
  ggchRelocAllChAddr(base, ggchClearDataHeapStartAddr);
#endif

#ifdef GG_INCLUDE_LINK_LAYER_MODEM_RELAY
  ggchRelocAllChAddr(base, ggchLLMRheapStartAddr);
#endif

#ifdef GG_INCLUDE_DATA_MODEM
  ggchRelocAllChAddr(base, ggchModemHeapStartAddr);
#endif

#ifdef AUDIO
  ggchRelocAllChAddr(base, ggchAudioHeapStartAddr);
#endif

#ifdef GG_INCLUDE_CONFERENCING
#if (!defined (HDVIDEO) && !defined (HDCT))
  ggRelocAddr(base, &confHeapDesc.heapAddr);
#endif
#endif  

#ifdef GG_INCLUDE_DSIGT
  ggRelocAddr(base, &dsigtHeapDesc.heapAddr);
#endif
  
#if (defined(GG_INCLUDE_DSIGR_AAL2) || defined(GG_INCLUDE_DSIGR_RTP))
  ggRelocAddr(base, &dsigrHeapDesc.heapAddr);
#endif
  
  /* relocate hal heap */
  ggRelocAddr(base, &halHeapDesc.heapStartAddr);
  ggRelocAddr(base, &halHeapDesc.heapEndAddr);
  
  ggchRelocAllChAddr(base, ggTxNetwork_data);
  ggchRelocAllChAddr(base, &gg_siuheap_inst[0]);
  ggRelocAddr(base, &gg_compound_scratch);

  /* relocate GMP segments */
  {
    tint i;
    for(i = 0; i < GG_GMP_AREAS; i++) {
     ggRelocAddr(base, &gg_gmp_segments[i].area_start);
     ggRelocAddr(base, &gg_gmp_segments[i].area_end);
    }
  }
  
  /* AER relocation */
  #ifdef GG_INCLUDE_AER
  {
    tint i;
    for(i = 0; i < GG_INCLUDE_AER; i++) {
      ggRelocAddr(base, &aerHeapDesc[i].heapAddr);
    }
  }
  #endif

  ggchRelocEcoBufs(base);
}
#endif

#if defined(GG_INCLUDE_G723) && defined(GG_G723_BUFF_SWAP_ENABLE)
#pragma DATA_SECTION(g723EncSwapBuffDesc, ".bufswap_bss")
 ggSwapBuffDesc_t g723EncSwapBuffDesc[GG_NUM_G723_ENC_SWAP_BUFS]=
	{
  /**************************** Swap Buffer 1 ********************/	
	{
	 { /* Source addresses */
                  
/* Expanding $ch = 1 */
	  (void *)GG_G723_ENC_B3_C1_START,
/* End expansion $ch = 1 */
/* Expanding $ch = 2 */
	  (void *)GG_G723_ENC_B3_C2_START,
/* End expansion $ch = 2 */

	 },
	 /* Destination address */
	  (void *)GG_G723_ENC_B3_SWAP_START,
	 /* Size */
	  GG_G723_ENC_B3_L,
	}
   };
#pragma DATA_SECTION(g723DecSwapBuffDesc, ".bufswap_bss")
 /* G723 Decoder Swap buffers */
ggSwapBuffDesc_t g723DecSwapBuffDesc[GG_NUM_G723_DEC_SWAP_BUFS]=
	{
  /**************************** Swap Buffer 1 ********************/	
	 {
	  { /* Source addresses */
                   
/* Expanding $ch = 1 */
	  (void *)GG_G723_DEC_B1_C1_START,
/* End expansion $ch = 1 */
/* Expanding $ch = 2 */
	  (void *)GG_G723_DEC_B1_C2_START,
/* End expansion $ch = 2 */

	 },
	 /* Destination address */
	  (void *)GG_G723_DEC_B1_SWAP_START,
	 /* Size */
	  GG_G723_DEC_B1_L,
	}
   };

#pragma DATA_SECTION(g723SwapBuffDesc, ".bufswap_bss")
ggCodecSwapBuffDesc_t g723SwapBuffDesc={

#ifdef GG_INCLUDE_G723               
         GG_NUM_G723_ENC_SWAP_BUFS,
		 g723EncSwapBuffDesc,
		 GG_NUM_G723_DEC_SWAP_BUFS,
		 g723DecSwapBuffDesc,
#else
         0,
		 NULL,
		 0,
		 NULL,
#endif
};

#endif /* if GG_INCLUDE_G723 && G723_SWAP_BUFF_ENABLE  */



#if defined(GG_INCLUDE_G729AB) && defined(GG_G729AB_BUFF_SWAP_ENABLE)
#pragma DATA_SECTION(g729abEncSwapBuffDesc, ".bufswap_bss")
ggSwapBuffDesc_t g729abEncSwapBuffDesc[GG_NUM_G729AB_ENC_SWAP_BUFS]=
	{
  /**************************** Swap Buffer 1 ********************/	
	 {
	 { /* Source addresses */
                  
/* Expanding $ch = 1 */
	  (void *)GG_G729AB_ENC_B2_C1_START,
/* End expansion $ch = 1 */
/* Expanding $ch = 2 */
	  (void *)GG_G729AB_ENC_B2_C2_START,
/* End expansion $ch = 2 */

	 },
	 /* Destination address */
	  (void *)GG_G729AB_ENC_B2_SWAP_START,
	 /* Size */
	  GG_G729AB_ENC_B2_L,
	}
   };
#pragma DATA_SECTION(g729abDecSwapBuffDesc, ".bufswap_bss")
 /* G729AB Decoder Swap buffers */
ggSwapBuffDesc_t g729abDecSwapBuffDesc[GG_NUM_G729AB_DEC_SWAP_BUFS]=
	{
  /**************************** Swap Buffer 1 ********************/	
	 {
	  { /* Source addresses */
                   
/* Expanding $ch = 1 */
	  (void *)GG_G729AB_DEC_B1_C1_START,
/* End expansion $ch = 1 */
/* Expanding $ch = 2 */
	  (void *)GG_G729AB_DEC_B1_C2_START,
/* End expansion $ch = 2 */

	 },
	 /* Destination address */
	  (void *)GG_G729AB_DEC_B1_SWAP_START,
	 /* Size */
	  GG_G729AB_DEC_B1_L,
	},
   };

#pragma DATA_SECTION(g729abSwapBuffDesc, ".bufswap_bss")
ggCodecSwapBuffDesc_t g729abSwapBuffDesc={

#ifdef GG_INCLUDE_G729AB               
         GG_NUM_G729AB_ENC_SWAP_BUFS,
		 g729abEncSwapBuffDesc,
		 GG_NUM_G729AB_DEC_SWAP_BUFS,
		 g729abDecSwapBuffDesc,
#else
         0,
		 NULL,
		 0,
		 NULL,
#endif
};

#endif /* end of if INCLUDE_G729AB && G729AB_SWAP_BUFF_ENABLE */




/* Module swap space addresses */

#ifdef SIU_CH_SWAP

ggModuleDataSwapDesc_t ggModuleDataSwapDesc[] =
{

#ifdef GG_INCLUDE_PCM
 #ifdef ER_PCM_CONSTSWAP_START
   { VCT_8APCM, 0, {  (tulong)(ER_PCM_CONSTSWAP_START), (tulong)(IR_PCM_CONSTSWAP_START), PCM_CONSTSWAP_L }},
 #endif 
#endif

#ifdef GG_INCLUDE_G726
 #ifdef ER_G726_CONSTSWAP_START
   { VCT_2ADPCM, 0, {  (tulong)(ER_G726_CONSTSWAP_START), (tulong)(IR_G726_CONSTSWAP_START), G726_CONSTSWAP_L }},
 #endif 
#endif

#ifdef GG_INCLUDE_G727
 #ifdef ER_G727_CONSTSWAP_START
   { VCT_E4_2ADPCM, 0, {  (tulong)(ER_G727_CONSTSWAP_START), (tulong)(IR_G727_CONSTSWAP_START), G727_CONSTSWAP_L }},
 #endif 
#endif

#ifdef GG_INCLUDE_G729AB
 #ifdef ER_G729AB_CONSTSWAP_START
   { EVCT_G729AB, 0, {  (tulong)(ER_G729AB_CONSTSWAP_START), (tulong)(IR_G729AB_CONSTSWAP_START), G729AB_CONSTSWAP_L }},
 #endif 
#endif

/*#ifdef GG_INCLUDE_G729
 #ifdef ER_G729AB_CONSTSWAP_START
   { EVCT_G729AB, 0, {  (tulong)(ER_G729AB_CONSTSWAP_START), (tulong)(IR_G729AB_CONSTSWAP_START), G729AB_CONSTSWAP_L }},
 #endif  
#endif
*/

#ifdef GG_INCLUDE_G729E
 #ifdef ER_G729E_CONSTSWAP_START
   { EVCT_G729E, 0, {  (tulong)(ER_G729E_CONSTSWAP_START), (tulong)(IR_G729E_CONSTSWAP_START), G729E_CONSTSWAP_L }},
 #endif 
#endif

#ifdef GG_INCLUDE_G723
 #ifdef ER_G723_CONSTSWAP_START
   { EVCT_G723_53, 0, {  (tulong)(ER_G723_CONSTSWAP_START), (tulong)(IR_G723_CONSTSWAP_START), G723_CONSTSWAP_L }},
 #endif 
#endif

#ifdef GG_INCLUDE_G728
 #ifdef ER_G728_CONSTSWAP_START
   { EVCT_LDCELP_16K, 0, {  (tulong)(ER_G728_CONSTSWAP_START), (tulong)(IR_G728_CONSTSWAP_START), G728_CONSTSWAP_L }},
 #endif 
#endif

/*
#ifdef GG_INCLUDE_GSMEFR
  
#endif

#ifdef GG_INCLUDE_GSMFR
  
#endif

#ifdef GG_INCLUDE_ILBC
#endif
*/


#ifdef GG_INCLUDE_G722
 #ifdef ER_G722_CONSTSWAP_START
   { VCT_E8_6ADPCM, 0, {  (tulong)(ER_G722_CONSTSWAP_START), (tulong)(IR_G722_CONSTSWAP_START), G722_CONSTSWAP_L }},
 #endif 
#endif

#ifdef GG_INCLUDE_GSMAMR
 #ifdef ER_GSMAMR_CONSTSWAP_START
   { EVCT_GSMAMR, 0, {  (tulong)(ER_GSMAMR_CONSTSWAP_START), (tulong)(IR_GSMAMR_CONSTSWAP_START), GSMAMR_CONSTSWAP_L }},
 #endif 
#endif


#ifdef GG_INCLUDE_G722_2
 #ifdef ER_WBAMR_CONSTSWAP_START
   { EVCT_GSM_WBAMR, 0, {  (tulong)(ER_WBAMR_CONSTSWAP_START), (tulong)(IR_WBAMR_CONSTSWAP_START), WBAMR_CONSTSWAP_L }},
 #endif 
#endif

/*
#ifdef GG_INCLUDE_EVRC
#endif

#ifdef GG_INCLUDE_SMV
#endif

#ifdef GG_INCLUDE_MSU
#endif
 

#if defined(AUDIO)
#ifdef GG_INCLUDE_MP3
  i = 0;
  ret_val |= platformInitMP3 (i++); 
#endif
#endif
*/

  { -1, 0, {  NULL, NULL, 0} } /* End Indication */
}; /* End of const ggModuleDataSwapDesc_t ggModuleDataSwapDesc[] */

#endif
/* Eco usage for non-voice channels (using NEU for messaging */
#ifdef NDU_UTOPIA 
const ggNvEcoBuffDesc_t ggNvBuffDesc[GG_NV_ECO_BUFF_NUM] = 
{

  /* Buffers for high priority messages */
  GG_NUM_NEU_BUFF,                                                   /* NEU Buffers */
  (word *)GG_UTNDU_NEU_MSG_INST_START,			    GG_UTNDU_NEU_INST_L,
  (word *)GG_UTNDU_NEU_MSG_SSSAR_START,             GG_UTNDU_NEU_SSSAR_L,
  (word *)GG_UTNDU_NEU_MSG_TX_SCRATCH_START,        GG_UTNDU_NEU_TX_SCRATCH_L,
  (word *)GG_UTNDU_NEU_MSG_TX_HEADER_START,		    GG_UTNDU_NEU_TX_HEADER_L,
  (word *)GG_UTNDU_NEU_MSG_RX_PKTASSEM_START,  	    GG_UTNDU_NEU_RX_PKTASSEM_L,

  /* Buffers for announcement (block requests) */
  GG_NUM_NEU_BUFF,
  (word *)GG_UTNDU_NEU_BLK_INST_START,				GG_UTNDU_NEU_INST_L,
  (word *)GG_UTNDU_NEU_BLK_SSSAR_START,             GG_UTNDU_NEU_SSSAR_L,
  (word *)GG_UTNDU_NEU_BLK_TX_SCRATCH_START,		GG_UTNDU_NEU_TX_SCRATCH_L,
  (word *)GG_UTNDU_NEU_BLK_TX_HEADER_START,			GG_UTNDU_NEU_TX_HEADER_L,
  (word *)GG_UTNDU_NEU_BLK_RX_PKTASSEM_START,		GG_UTNDU_NEU_RX_PKTASSEM_L,

  /* Buffers for keep alives */
  GG_NUM_NEU_BUFF,
  (word *)GG_UTNDU_NEU_HLT_INST_START,				GG_UTNDU_NEU_INST_L,
  (word *)GG_UTNDU_NEU_HLT_SSSAR_START,             GG_UTNDU_NEU_SSSAR_L,
  (word *)GG_UTNDU_NEU_HLT_TX_SCRATCH_START,	    GG_UTNDU_NEU_TX_SCRATCH_L,
  (word *)GG_UTNDU_NEU_HLT_TX_HEADER_START,		    GG_UTNDU_NEU_HLT_HEADER_L,
  (word *)GG_UTNDU_NEU_HLT_RX_PKTASSEM_START,	    GG_UTNDU_NEU_HLT_RX_PKTASSEM_L

};
#endif

#ifdef NDU_GMAC
/* Eco usage for non-voice channels (using NEU for messaging */
const ggNvEcoBuffDesc_t ggNvBuffDesc[GG_NV_ECO_BUFF_NUM] = 
{

  /* Buffers for high priority messages */
  GG_NUM_NEU_BUFF,                                                   /* NEU Buffers */
  (word *)GG_GMNDU_NEU_MSG_INST_START,			    GG_GMNDU_NEU_INST_L,
  (word *)0x0000000,                                0,
  (word *)GG_GMNDU_NEU_MSG_TX_SCRATCH_START,        GG_GMNDU_NEU_TX_SCRATCH_L,
  (word *)GG_GMNDU_NEU_MSG_TX_HEADER_START,		    GG_GMNDU_NEU_TX_HEADER_L,
  (word *)GG_GMNDU_NEU_MSG_RX_PKTASSEM_START,  	    GG_GMNDU_NEU_RX_PKTASSEM_L,

  /* Buffers for announcement (block requests) */
  GG_NUM_NEU_BUFF,
  (word *)GG_GMNDU_NEU_BLK_INST_START,				GG_GMNDU_NEU_INST_L,
  (word *)0x0000000,                                0,
  (word *)GG_GMNDU_NEU_BLK_TX_SCRATCH_START,		GG_GMNDU_NEU_TX_SCRATCH_L,
  (word *)GG_GMNDU_NEU_BLK_TX_HEADER_START,			GG_GMNDU_NEU_TX_HEADER_L,
  (word *)GG_GMNDU_NEU_BLK_RX_PKTASSEM_START,		GG_GMNDU_NEU_RX_PKTASSEM_L,

  /* Buffers for keep alives */
  GG_NUM_NEU_BUFF,
  (word *)GG_GMNDU_NEU_HLT_INST_START,				GG_GMNDU_NEU_INST_L,
  (word *)0x0000000,                                0,
  (word *)GG_GMNDU_NEU_HLT_TX_SCRATCH_START,	    GG_GMNDU_NEU_TX_SCRATCH_L,
  (word *)GG_GMNDU_NEU_HLT_TX_HEADER_START,		    GG_GMNDU_NEU_HLT_HEADER_L,
  (word *)GG_GMNDU_NEU_HLT_RX_PKTASSEM_START,	    GG_GMNDU_NEU_HLT_RX_PKTASSEM_L,

  /* Buffers for streaming out trace to PC */
  GG_NUM_NEU_BUFF,
  (word *)GG_GMNDU_NEU_TRACE_INST_START,            GG_GMNDU_NEU_INST_L,
  (word *)0x0000000,                                0,
  (word *)GG_GMNDU_NEU_TRACE_TX_SCRATCH_START,      GG_GMNDU_NEU_TX_SCRATCH_L,
  (word *)GG_GMNDU_NEU_TRACE_TX_HEADER_START,       GG_GMNDU_NEU_TX_HEADER_L,
  (word *)GG_GMNDU_NEU_TRACE_RX_PKTASSEM_START,     GG_GMNDU_NEU_RX_PKTASSEM_L

};
#endif
#ifdef NDU_UTOPIA
/* Utopia NDU message aal5 instances */
const ggutNduAal5Desc_t ggutNduAal5Desc =
{
  (word *)GG_UTNDU_MSG_AAL5_HIGH_INST_START,      
  (word *)GG_UTNDU_MSG_AAL5_NORMAL_INST_START,       
  (word *)GG_UTNDU_MSG_AAL5_LOW_INST_START,
  (tuint) GG_UTNDU_AAL5_L 
};
#endif

/* Utopia NDU buffers */
#ifdef NDU_UTOPIA
const ggutNduDesc_t utNduHeapDesc = 
{ GG_NUM_UTOPIA_NDU_BUFF,
  (word *)GG_UTNDU_MSG_HIGH_START,       GG_NDU_MSG_HIGH_FIFO_L,
  (word *)GG_UTNDU_MSG_NORMAL_START,     GG_NDU_MSG_NORMAL_FIFO_L,
  (word *)GG_UTNDU_MSG_LOW_START,        GG_NDU_MSG_LOW_FIFO_L
};
#endif

const tuint  GG_SWAP_OFFSET        = (GG_MAX_NUM_CHANNELS + GG_MAX_PKT2PKT_CHANNELS);
/* Gmac NDU buffers */
#ifdef NDU_GMAC

const gggmNduDesc_t gmacNduHeapDesc = 
{ GG_NUM_MAC_NDU_BUFF,
  (word *)GG_GMNDU_MSG_HIGH_START,       GG_NDU_MSG_HIGH_FIFO_L,
  (word *)GG_GMNDU_MSG_NORMAL_START,     GG_NDU_MSG_NORMAL_FIFO_L,
  (word *)GG_GMNDU_MSG_LOW_START,        GG_NDU_MSG_LOW_FIFO_L
};
#endif


extern tuint ggPlcBuffOffsets[];
extern tuint ggRxNmuBuffOffsets[];
extern tuint ggTxNmuBuffOffsets[];


/* If any reloc is done */
#if defined(GG_INCLUDE_RELOC_RTP_MSU)  || \
    defined(GG_INCLUDE_RELOC_RTCP_MSU) || \
    defined(GG_INCLUDE_RELOC_PLR)      || \
    defined(PLR_USE_GMP_SUPPLEMENT)    || \
    defined(GG_INCLUDE_RELOC_PLC)      || \
    defined(GG_INCLUDE_RELOC_RX_NMU)   || \
    defined(GG_INCLUDE_RELOC_TX_NMU)

ggDynHeapModInfo_t ModInfo[]=
{
#ifdef GG_INCLUDE_RELOC_RTP_MSU
  /* RTP MSU  */  
  SIU_MID_MSU_RTP, 
  GG_DYNHEAP_RTP_MSU_GRP_ID,
  GG_RELOC_RTP_MSU_INFO,0,
  GG_DYNHEAP_RTP_MSU_OFFSET,
  GG_DYNHEAP_RTP_MSU_NUMBUFF,
  ggRtpMsuBuffOffsets,
#endif
#ifdef GG_INCLUDE_RELOC_RTCP_MSU
  /* RTP MSU  */  
  SIU_MID_MSU_RTCP,  
  GG_DYNHEAP_RTCP_MSU_GRP_ID,
  GG_RELOC_RTCP_MSU_INFO,0,
  GG_DYNHEAP_RTCP_MSU_OFFSET,
  GG_DYNHEAP_RTCP_MSU_NUMBUFF,
  ggRtcpMsuBuffOffsets,
#endif
#ifdef GG_INCLUDE_RELOC_PLR
  /* PLR  */  
  SIU_MID_PLR,  
  GG_DYNHEAP_PLR_GRP_ID,
  GG_RELOC_PLR_INFO,0,
  GG_DYNHEAP_PLR_OFFSET,
  GG_DYNHEAP_PLR_NUMBUFF,
  ggPlrBuffOffsets,
#elif defined(PLR_USE_GMP_SUPPLEMENT)
  /* PLR  */  
  SIU_MID_PLRVBD,  
  GG_DYNHEAP_PLR_SUPPGMP_GRP_ID,
  GG_RELOC_PLR_GMPSUPP_INFO,0,
  GG_DYNHEAP_PLR_SUPPGMP_OFFSET,
  GG_DYNHEAP_PLR_SUPPGMP_NUMBUFF,
  ggPlrSuppBuffOffsets,
#endif

#ifdef GG_INCLUDE_RELOC_PLC
  /* PLC  */
  SIU_MID_PLC,
  GG_DYNHEAP_PLC_GRP_ID,
  GG_RELOC_PLC_INFO,0,
  GG_DYNHEAP_PLC_OFFSET,
  GG_DYNHEAP_PLC_NUMBUFF,
  ggPlcBuffOffsets,
#endif
#ifdef GG_INCLUDE_RELOC_RX_NMU
  /* RX NMU  */
  SIU_MID_RX_NMU,   
  GG_DYNHEAP_RX_NMU_GRP_ID,
  GG_RELOC_RX_NMU_INFO,0,
  GG_DYNHEAP_RX_NMU_OFFSET,
  GG_DYNHEAP_RX_NMU_NUMBUFF,
  ggRxNmuBuffOffsets,
#endif
#ifdef GG_INCLUDE_RELOC_TX_NMU
  /* TX NMU */  
  SIU_MID_TX_NMU,   
  GG_DYNHEAP_TX_NMU_GRP_ID,
  GG_RELOC_TX_NMU_INFO,0,
  GG_DYNHEAP_TX_NMU_OFFSET,
  GG_DYNHEAP_TX_NMU_NUMBUFF,
  ggTxNmuBuffOffsets 
#endif
};

ggDynHeapDesc_t dynHeapDesc = 
{ 
  GG_DYNHEAP_TOTAL_NUM_MODULES,
  GG_DYNHEAP_MAX_BUFF_PER_MOD,
  ModInfo
};

/* Dynamic heap relocation and location info for 
 * modules that can be allocatable from dynamic heap.
 * Relative location is not important. This is done
 * to allow flexibilty in module location in a chunk.
 */
const ggDynheapModInfo_t gg_dynheap_mod_info[] = {

#ifdef GG_INCLUDE_RELOC_RTP_MSU
  SIU_MID_MSU_RTP, GG_DYNHEAP_RTP_MSU_CHNK_LOC,
#endif 

#ifdef GG_INCLUDE_RELOC_RTCP_MSU
  SIU_MID_MSU_RTCP, GG_DYNHEAP_RTCP_MSU_CHNK_LOC,
#endif 

#ifdef GG_INCLUDE_RELOC_PLR
  SIU_MID_PLR, GG_DYNHEAP_PLR_CHNK_LOC,
#elif defined(PLR_USE_GMP_SUPPLEMENT)
  SIU_MID_PLRVBD, GG_DYNHEAP_PLR_SUPPGMP_CHNK_LOC,
#endif 

#ifdef GG_INCLUDE_RELOC_PLC
  SIU_MID_PLC, GG_DYNHEAP_PLC_CHNK_LOC,
#endif

#ifdef GG_INCLUDE_RELOC_RX_NMU
  SIU_MID_RX_NMU, GG_DYNHEAP_RX_NMU_CHNK_LOC,
#endif 

#ifdef GG_INCLUDE_RELOC_TX_NMU
  SIU_MID_TX_NMU, GG_DYNHEAP_TX_NMU_CHNK_LOC,
#endif
   
  
  0, -1
};

#endif /* if any reloc is done */

/* RTTRACE buffers */
#pragma DATA_SECTION (gg_rttrace_enable, ".rttrace");
#pragma DATA_SECTION (gg_rttrace_buffer0, ".rttrace");
#pragma DATA_SECTION (gg_rttrace_buffer1, ".rttrace");
#pragma DATA_SECTION (gg_rttrace_buffers, ".rttrace");
/* Channel enable bitfields */
utlRtTraceEnable_t gg_rttrace_enable[GG_MAX_NUM_CHANNELS + GG_MAX_PKT2PKT_CHANNELS];

/* Message buffers */
word gg_rttrace_buffer0[GG_RTTRACE_BUFSIZE];
word gg_rttrace_buffer1[GG_RTTRACE_BUFSIZE];
word *gg_rttrace_buffers[] = { gg_rttrace_buffer0, gg_rttrace_buffer1 };

extern word gg_alloc_type_fiu[];

/* QM buffers */
#if (GG_QM_RX_LINKED_BUF_1_SIZE) 
  #pragma DATA_SECTION(rxlinkramQ1, ".cppiMemRXLinkRamQ1")
  #pragma DATA_ALIGN(rxlinkramQ1, 128)
  word rxlinkramQ1[GG_QM_RX_LINKED_BUF_1_SIZE * GG_QM_RX_LINKED_BUF_1_NBUFS];
#endif

#if (GG_QM_RX_LINKED_BUF_2_SIZE) 
  #pragma DATA_SECTION(rxlinkramQ2, ".cppiMemRXLinkRamQ2")
  #pragma DATA_ALIGN(rxlinkramQ2, 128)
  word rxlinkramQ2[GG_QM_RX_LINKED_BUF_2_SIZE * GG_QM_RX_LINKED_BUF_2_NBUFS];
#endif

#if (GG_QM_RX_LINKED_BUF_3_SIZE) 
  #pragma DATA_SECTION(rxlinkramQ3, ".cppiMemRXLinkRamQ3")
  #pragma DATA_ALIGN(rxlinkramQ3, 128)
  word rxlinkramQ3[GG_QM_RX_LINKED_BUF_3_SIZE * GG_QM_RX_LINKED_BUF_3_NBUFS];
#endif

#if (GG_QM_RX_LINKED_BUF_4_SIZE) 
  #pragma DATA_SECTION(rxlinkramQ4, ".cppiMemRXLinkRamQ4")
  #pragma DATA_ALIGN(rxlinkramQ4, 128)
  word rxlinkramQ4[GG_QM_RX_LINKED_BUF_4_SIZE * GG_QM_RX_LINKED_BUF_4_NBUFS];
#endif

#if (GG_QM_TX_LINKED_BUF_1_SIZE) 
  #pragma DATA_SECTION(txlinkramQ1, ".cppiMemTXLinkRamQ1")
  #pragma DATA_ALIGN(txlinkramQ1, 128)
  word txlinkramQ1[GG_QM_TX_LINKED_BUF_1_SIZE * GG_QM_TX_LINKED_BUF_1_NBUFS];
#endif

#if (GG_QM_TX_LINKED_BUF_2_SIZE) 
  #pragma DATA_SECTION(txlinkramQ2, ".cppiMemTXLinkRamQ2")
  #pragma DATA_ALIGN(txlinkramQ2, 128)
  word txlinkramQ2[GG_QM_TX_LINKED_BUF_2_SIZE * GG_QM_TX_LINKED_BUF_2_NBUFS];
#endif

#if (GG_QM_TX_LINKED_BUF_3_SIZE) 
  #pragma DATA_SECTION(txlinkramQ3, ".cppiMemTXLinkRamQ3")
  #pragma DATA_ALIGN(txlinkramQ3, 128)
  word txlinkramQ3[GG_QM_TX_LINKED_BUF_3_SIZE * GG_QM_TX_LINKED_BUF_3_NBUFS];
#endif

#if (GG_QM_TX_LINKED_BUF_4_SIZE) 
  #pragma DATA_SECTION(txlinkramQ4, ".cppiMemTXLinkRamQ4")
  #pragma DATA_ALIGN(txlinkramQ4, 128)
  word txlinkramQ4[GG_QM_TX_LINKED_BUF_4_SIZE * GG_QM_TX_LINKED_BUF_4_NBUFS];
#endif

#if (GG_QM_DESC_SIZE)
  #pragma DATA_SECTION(QMemDescRam, ".QMemDescRam")
  #pragma DATA_ALIGN(QMemDescRam, 128)
  word QMemDescRam[GG_QM_DESC_SIZE * GG_QM_NUM_DESCS];
#endif

const ggAllocType_t gg_alloc_type[]=
{ 
#ifdef GG_FIU_ALLOC_MULTIPLE_SLOTS
  {
  	SIU_MID_FIU,
	&gg_alloc_type_fiu[0],
  },
#endif
  {
  	0,
	(word *)NULL
  }
};

/* nothing past this point */
